@@ -4,7 +4,7 @@
  * Copyright (c) 2008 Jan Kratochvil <jan.kratochvil@redhat.com>
  * Copyright (c) 2009-2013 Denys Vlasenko <dvlasenk@redhat.com>
  * Copyright (c) 2006-2015 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2014-2018 The strace developers.
+ * Copyright (c) 2014-2019 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -25,10 +25,10 @@
 #if defined IA64
 # define ARG_FLAGS	0
 # define ARG_STACK	1
-# define ARG_STACKSIZE	(tcp->scno == __NR_clone2 ? 2 : -1)
-# define ARG_PTID	(tcp->scno == __NR_clone2 ? 3 : 2)
-# define ARG_CTID	(tcp->scno == __NR_clone2 ? 4 : 3)
-# define ARG_TLS	(tcp->scno == __NR_clone2 ? 5 : 4)
+# define ARG_STACKSIZE	(shuffle_scno(tcp->scno) == __NR_clone2 ? 2 : -1)
+# define ARG_PTID	(shuffle_scno(tcp->scno) == __NR_clone2 ? 3 : 2)
+# define ARG_CTID	(shuffle_scno(tcp->scno) == __NR_clone2 ? 4 : 3)
+# define ARG_TLS	(shuffle_scno(tcp->scno) == __NR_clone2 ? 5 : 4)
 #elif defined S390 || defined S390X
 # define ARG_STACK	0
 # define ARG_FLAGS	1
@@ -42,7 +42,7 @@
 # define ARG_PTID	2
 # define ARG_CTID	((current_personality != 1) ? 3 : 4)
 # define ARG_TLS	((current_personality != 1) ? 4 : 3)
-#elif defined ALPHA || defined TILE || defined OR1K || defined RISCV
+#elif defined ALPHA || defined TILE || defined OR1K || defined CSKY
 # define ARG_FLAGS	0
 # define ARG_STACK	1
 # define ARG_PTID	2
@@ -64,22 +64,24 @@ print_tls_arg(struct tcb *const tcp, const kernel_ulong_t addr)
 	if (current_personality == 1)
 # endif
 	{
-		print_user_desc(tcp, tcp->u_arg[ARG_TLS], USER_DESC_BOTH);
+		print_user_desc(tcp, addr, USER_DESC_BOTH);
 	}
 # if SUPPORTED_PERSONALITIES > 1
 	else
 # endif
 #endif /* HAVE_STRUCT_USER_DESC */
 	{
-		printaddr(tcp->u_arg[ARG_TLS]);
+		printaddr(addr);
 	}
 }
 
 SYS_FUNC(clone)
 {
-	if (exiting(tcp)) {
-		const char *sep = "|";
-		kernel_ulong_t flags = tcp->u_arg[ARG_FLAGS];
+	const kernel_ulong_t flags = tcp->u_arg[ARG_FLAGS] & ~CSIGNAL;
+
+	if (entering(tcp)) {
+		const unsigned int sig = tcp->u_arg[ARG_FLAGS] & CSIGNAL;
+
 		tprints("child_stack=");
 		printaddr(tcp->u_arg[ARG_STACK]);
 		tprints(", ");
@@ -89,18 +91,43 @@ SYS_FUNC(clone)
 				tcp->u_arg[ARG_STACKSIZE]);
 #endif
 		tprints("flags=");
-		if (!printflags64(clone_flags, flags & ~CSIGNAL, NULL))
-			sep = "";
-		if ((flags & CSIGNAL) != 0) {
-			tprints(sep);
-			printsignal(flags & CSIGNAL);
+		if (flags) {
+			printflags64(clone_flags, flags, "CLONE_???");
+			if (sig) {
+				tprints("|");
+				printsignal(sig);
+			}
+		} else {
+			if (sig)
+				printsignal(sig);
+			else
+				tprints("0");
 		}
-		if ((flags & (CLONE_PARENT_SETTID|CLONE_CHILD_SETTID
+		/*
+		 * TODO on syscall entry:
+		 * We can clear CLONE_PTRACE here since it is an ancient hack
+		 * to allow us to catch children, and we use another hack for that.
+		 * But CLONE_PTRACE can conceivably be used by malicious programs
+		 * to subvert us. By clearing this bit, we can defend against it:
+		 * in untraced execution, CLONE_PTRACE should have no effect.
+		 *
+		 * We can also clear CLONE_UNTRACED, since it allows to start
+		 * children outside of our control. At the moment
+		 * I'm trying to figure out whether there is a *legitimate*
+		 * use of this flag which we should respect.
+		 */
+		if ((flags & (CLONE_PARENT_SETTID|CLONE_PIDFD|CLONE_CHILD_SETTID
 			      |CLONE_CHILD_CLEARTID|CLONE_SETTLS)) == 0)
-			return 0;
-		if (flags & CLONE_PARENT_SETTID) {
-			tprints(", parent_tidptr=");
-			printaddr(tcp->u_arg[ARG_PTID]);
+			return RVAL_DECODED;
+	} else {
+		if (flags & (CLONE_PARENT_SETTID|CLONE_PIDFD)) {
+			kernel_ulong_t addr = tcp->u_arg[ARG_PTID];
+
+			tprints(", parent_tid=");
+			if (flags & CLONE_PARENT_SETTID)
+				printnum_int(tcp, addr, "%u");
+			else
+				printnum_fd(tcp, addr);
 		}
 		if (flags & CLONE_SETTLS) {
 			tprints(", tls=");
@@ -111,18 +138,6 @@ SYS_FUNC(clone)
 			printaddr(tcp->u_arg[ARG_CTID]);
 		}
 	}
-	/* TODO on syscall entry:
-	 * We can clear CLONE_PTRACE here since it is an ancient hack
-	 * to allow us to catch children, and we use another hack for that.
-	 * But CLONE_PTRACE can conceivably be used by malicious programs
-	 * to subvert us. By clearing this bit, we can defend against it:
-	 * in untraced execution, CLONE_PTRACE should have no effect.
-	 *
-	 * We can also clear CLONE_UNTRACED, since it allows to start
-	 * children outside of our control. At the moment
-	 * I'm trying to figure out whether there is a *legitimate*
-	 * use of this flag which we should respect.
-	 */
 	return 0;
 }
 
