@@ -12,7 +12,7 @@
 [  1] = { 1,	TM,		SEN(io_destroy),		"io_destroy"		},
 [  2] = { 3,	0,		SEN(io_submit),			"io_submit"		},
 [  3] = { 3,	0,		SEN(io_cancel),			"io_cancel"		},
-[  4] = { 5,	0,		SEN(io_getevents),		"io_getevents"		},
+[  4] = { 5,	0,		SEN(io_getevents_time32),	"io_getevents"		},
 [  5] = { 5,	TF,		SEN(setxattr),			"setxattr"		},
 [  6] = { 5,	TF,		SEN(setxattr),			"lsetxattr"		},
 [  7] = { 5,	TD,		SEN(fsetxattr),			"fsetxattr"		},
@@ -80,8 +80,8 @@
 [ 69] = { 5,	TD,		SEN(preadv),			"preadv"		},
 [ 70] = { 5,	TD,		SEN(pwritev),			"pwritev"		},
 [ 71] = { 4,	TD|TN,		SEN(sendfile64),		"sendfile64"		},
-[ 72] = { 6,	TD,		SEN(pselect6),			"pselect6"		},
-[ 73] = { 5,	TD,		SEN(ppoll),			"ppoll"			},
+[ 72] = { 6,	TD,		SEN(pselect6_time32),		"pselect6"		},
+[ 73] = { 5,	TD,		SEN(ppoll_time32),		"ppoll"			},
 [ 74] = { 4,	TD|TS,		SEN(signalfd4),			"signalfd4"		},
 [ 75] = { 4,	TD,		SEN(vmsplice),			"vmsplice"		},
 [ 76] = { 6,	TD,		SEN(splice),			"splice"		},
@@ -98,9 +98,9 @@
 [ 84] = { 6,	TD,		SEN(sync_file_range),		"sync_file_range"	},
 #endif
 [ 85] = { 2,	TD,		SEN(timerfd_create),		"timerfd_create"	},
-[ 86] = { 4,	TD,		SEN(timerfd_settime),		"timerfd_settime"	},
-[ 87] = { 2,	TD,		SEN(timerfd_gettime),		"timerfd_gettime"	},
-[ 88] = { 4,	TD|TF,		SEN(utimensat),			"utimensat"		},
+[ 86] = { 4,	TD,		SEN(timerfd_settime32),		"timerfd_settime"	},
+[ 87] = { 2,	TD,		SEN(timerfd_gettime32),		"timerfd_gettime"	},
+[ 88] = { 4,	TD|TF,		SEN(utimensat_time32),		"utimensat"		},
 [ 89] = { 1,	TF,		SEN(acct),			"acct"			},
 [ 90] = { 2,	0,		SEN(capget),			"capget"		},
 [ 91] = { 2,	0,		SEN(capset),			"capset"		},
@@ -110,24 +110,24 @@
 [ 95] = { 5,	TP,		SEN(waitid),			"waitid"		},
 [ 96] = { 1,	0,		SEN(set_tid_address),		"set_tid_address"	},
 [ 97] = { 1,	TP,		SEN(unshare),			"unshare"		},
-[ 98] = { 6,	0,		SEN(futex),			"futex"			},
+[ 98] = { 6,	0,		SEN(futex_time32),		"futex"			},
 [ 99] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [100] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
-[101] = { 2,	0,		SEN(nanosleep),			"nanosleep"		},
+[101] = { 2,	0,		SEN(nanosleep_time32),		"nanosleep"		},
 [102] = { 2,	0,		SEN(getitimer),			"getitimer"		},
 [103] = { 3,	0,		SEN(setitimer),			"setitimer"		},
 [104] = { 4,	0,		SEN(kexec_load),		"kexec_load"		},
 [105] = { 3,	0,		SEN(init_module),		"init_module"		},
 [106] = { 2,	0,		SEN(delete_module),		"delete_module"		},
 [107] = { 3,	0,		SEN(timer_create),		"timer_create"		},
-[108] = { 2,	0,		SEN(timer_gettime),		"timer_gettime"		},
+[108] = { 2,	0,		SEN(timer_gettime32),		"timer_gettime"		},
 [109] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
-[110] = { 4,	0,		SEN(timer_settime),		"timer_settime"		},
+[110] = { 4,	0,		SEN(timer_settime32),		"timer_settime"		},
 [111] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
-[112] = { 2,	0,		SEN(clock_settime),		"clock_settime"		},
-[113] = { 2,	0,		SEN(clock_gettime),		"clock_gettime"		},
-[114] = { 2,	0,		SEN(clock_getres),		"clock_getres"		},
-[115] = { 4,	0,		SEN(clock_nanosleep),		"clock_nanosleep"	},
+[112] = { 2,	0,		SEN(clock_settime32),		"clock_settime"		},
+[113] = { 2,	0,		SEN(clock_gettime32),		"clock_gettime"		},
+[114] = { 2,	0,		SEN(clock_getres_time32),	"clock_getres"		},
+[115] = { 4,	0,		SEN(clock_nanosleep_time32),	"clock_nanosleep"	},
 [116] = { 3,	0,		SEN(syslog),			"syslog"		},
 [117] = { 4,	0,		SEN(ptrace),			"ptrace"		},
 [118] = { 2,	0,		SEN(sched_setparam),		"sched_setparam"	},
@@ -139,7 +139,7 @@
 [124] = { 0,	0,		SEN(sched_yield),		"sched_yield"		},
 [125] = { 1,	0,		SEN(sched_get_priority_max),	"sched_get_priority_max"},
 [126] = { 1,	0,		SEN(sched_get_priority_min),	"sched_get_priority_min"},
-[127] = { 2,	0,		SEN(sched_rr_get_interval),	"sched_rr_get_interval"	},
+[127] = { 2,	0,		SEN(sched_rr_get_interval_time32),"sched_rr_get_interval"},
 [128] = { 0,	0,		SEN(restart_syscall),		"restart_syscall"	},
 [129] = { 2,	TS,		SEN(kill),			"kill"			},
 [130] = { 2,	TS,		SEN(kill),			"tkill"			},
@@ -149,7 +149,7 @@
 [134] = { 4,	TS,		SEN(rt_sigaction),		"rt_sigaction"		},
 [135] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [136] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
-[137] = { 4,	TS,		SEN(rt_sigtimedwait),		"rt_sigtimedwait"	},
+[137] = { 4,	TS,		SEN(rt_sigtimedwait_time32),	"rt_sigtimedwait"	},
 [138] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [139] = { 0,	TS,		SEN(rt_sigreturn),		"rt_sigreturn"		},
 [140] = { 3,	0,		SEN(setpriority),		"setpriority"		},
@@ -183,7 +183,7 @@
 [168] = { 3,	0,		SEN(getcpu),			"getcpu"		},
 [169] = { 2,	0,		SEN(gettimeofday),		"gettimeofday"		},
 [170] = { 2,	0,		SEN(settimeofday),		"settimeofday"		},
-[171] = { 1,	0,		SEN(adjtimex),			"adjtimex"		},
+[171] = { 1,	0,		SEN(adjtimex32),		"adjtimex"		},
 [172] = { 0,	PU|NF,		SEN(getpid),			"getpid"		},
 [173] = { 0,	PU|NF,		SEN(getppid),			"getppid"		},
 [174] = { 0,	PU|NF,		SEN(getuid),			"getuid"		},
@@ -194,8 +194,8 @@
 [179] = { 1,	0,		SEN(sysinfo),			"sysinfo"		},
 [180] = { 4,	TD,		SEN(mq_open),			"mq_open"		},
 [181] = { 1,	0,		SEN(mq_unlink),			"mq_unlink"		},
-[182] = { 5,	TD,		SEN(mq_timedsend),		"mq_timedsend"		},
-[183] = { 5,	TD,		SEN(mq_timedreceive),		"mq_timedreceive"	},
+[182] = { 5,	TD,		SEN(mq_timedsend_time32),	"mq_timedsend"		},
+[183] = { 5,	TD,		SEN(mq_timedreceive_time32),	"mq_timedreceive"	},
 [184] = { 2,	TD,		SEN(mq_notify),			"mq_notify"		},
 [185] = { 3,	TD,		SEN(mq_getsetattr),		"mq_getsetattr"		},
 [186] = { 2,	TI,		SEN(msgget),			"msgget"		},
@@ -204,7 +204,7 @@
 [189] = { 4,	TI,		SEN(msgsnd),			"msgsnd"		},
 [190] = { 3,	TI,		SEN(semget),			"semget"		},
 [191] = { 4,	TI,		SEN(semctl),			"semctl"		},
-[192] = { 4,	TI,		SEN(semtimedop),		"semtimedop"		},
+[192] = { 4,	TI,		SEN(semtimedop_time32),		"semtimedop"		},
 [193] = { 3,	TI,		SEN(semop),			"semop"			},
 [194] = { 3,	TI,		SEN(shmget),			"shmget"		},
 [195] = { 3,	TI,		SEN(shmctl),			"shmctl"		},
@@ -255,7 +255,7 @@
 [240] = { 4,	TP|TS,		SEN(rt_tgsigqueueinfo),		"rt_tgsigqueueinfo"	},
 [241] = { 5,	TD,		SEN(perf_event_open),		"perf_event_open"	},
 [242] = { 4,	TN,		SEN(accept4),			"accept4"		},
-[243] = { 5,	TN,		SEN(recvmmsg),			"recvmmsg"		},
+[243] = { 5,	TN,		SEN(recvmmsg_time32),		"recvmmsg"		},
 /* [244 ... 259] are arch specific */
 [260] = { 4,	TP,		SEN(wait4),			"wait4"			},
 [261] = { 4,	0,		SEN(prlimit64),			"prlimit64"		},
@@ -263,7 +263,7 @@
 [263] = { 6,	TD|TF,		SEN(fanotify_mark),		"fanotify_mark"		},
 [264] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [265] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
-[266] = { 2,	0,		SEN(clock_adjtime),		"clock_adjtime"		},
+[266] = { 2,	0,		SEN(clock_adjtime32),		"clock_adjtime"		},
 [267] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
 [268] = { 2,	TD,		SEN(setns),			"setns"			},
 [269] = { 4,	TN,		SEN(sendmmsg),			"sendmmsg"		},
@@ -289,9 +289,12 @@
 [289] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
 [290] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
 [291] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
-[292] = { 6,	0,		SEN(io_pgetevents),		"io_pgetevents"		},
+[292] = { 6,	0,		SEN(io_pgetevents_time32),	"io_pgetevents"		},
 [293] = { 4,	0,		SEN(rseq),			"rseq"			},
 [294] = { 5,	TD,		SEN(kexec_file_load),		"kexec_file_load"	},
+/* [295 ... 402] - reserved to sync up with other architectures */
+#include "syscallent-common-32.h"
+#include "syscallent-common.h"
 
 #undef sys_ARCH_mmap
 #undef ARCH_WANT_SYNC_FILE_RANGE2
