@@ -477,7 +477,7 @@
 [531] = { 0,	PU|NF,		SEN(geteuid),			"geteuid"		},
 [532] = { 0,	PU|NF,		SEN(getppid),			"getppid"		},
 /* all other architectures have common numbers for new syscalls, alpha is the exception */
-[534] = { 4,	TD|TS,		SEN(pidfd_send_signal),		"pidfd_send_signal"	},
-[535] = { 2,	TD,		SEN(io_uring_setup),		"io_uring_setup"	},
-[536] = { 6,	TD|TS,		SEN(io_uring_enter),		"io_uring_enter"	},
-[537] = { 4,	TD|TM,		SEN(io_uring_register),		"io_uring_register"	},
+/* 534 - 424 == 110 */
+#define BASE_NR 110
+#include "syscallent-common.h"
+#undef BASE_NR
