@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
  * Copyright (c) 1993, 1994, 1995 Rick Sladkey <jrs@world.std.com>
- * Copyright (c) 1995-2018 The strace developers.
+ * Copyright (c) 1995-2019 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -131,7 +131,7 @@
 [121] = { 2,	0,		SEN(setdomainname),		"setdomainname"		},
 [122] = { 1,	0,		SEN(uname),			"uname"			},
 [123] = { 3,	0,		SEN(modify_ldt),		"modify_ldt"		},
-[124] = { 1,	0,		SEN(adjtimex),			"adjtimex"		},
+[124] = { 1,	0,		SEN(adjtimex32),		"adjtimex"		},
 [125] = { 3,	TM|SI,		SEN(mprotect),			"mprotect"		},
 [126] = { 3,	TS,		SEN(sigprocmask),		"sigprocmask"		},
 [127] = { 2,	0,		SEN(create_module),		"create_module"		},
@@ -168,14 +168,14 @@
 [158] = { 0,	0,		SEN(sched_yield),		"sched_yield"		},
 [159] = { 1,	0,		SEN(sched_get_priority_max),	"sched_get_priority_max"},
 [160] = { 1,	0,		SEN(sched_get_priority_min),	"sched_get_priority_min"},
-[161] = { 2,	0,		SEN(sched_rr_get_interval),	"sched_rr_get_interval"	},
-[162] = { 2,	0,		SEN(nanosleep),			"nanosleep"		},
+[161] = { 2,	0,		SEN(sched_rr_get_interval_time32),"sched_rr_get_interval"},
+[162] = { 2,	0,		SEN(nanosleep_time32),		"nanosleep"		},
 [163] = { 5,	TM|SI,		SEN(mremap),			"mremap"		},
 [164] = { 3,	0,		SEN(setresuid16),		"setresuid"		},
 [165] = { 3,	0,		SEN(getresuid16),		"getresuid"		},
 [166] = { 5,	0,		SEN(vm86),			"vm86"			},
 [167] = { 5,	0,		SEN(query_module),		"query_module"		},
-[168] = { 3,	TD,		SEN(poll),			"poll"			},
+[168] = { 3,	TD,		SEN(poll_time32),		"poll"			},
 [169] = { 3,	0,		SEN(nfsservctl),		"nfsservctl"		},
 [170] = { 3,	0,		SEN(setresgid16),		"setresgid"		},
 [171] = { 3,	0,		SEN(getresgid16),		"getresgid"		},
@@ -184,7 +184,7 @@
 [174] = { 4,	TS,		SEN(rt_sigaction),		"rt_sigaction"		},
 [175] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [176] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
-[177] = { 4,	TS,		SEN(rt_sigtimedwait),		"rt_sigtimedwait"	},
+[177] = { 4,	TS,		SEN(rt_sigtimedwait_time32),	"rt_sigtimedwait"	},
 [178] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [179] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [180] = { 6,	TD,		SEN(pread),			"pread64"		},
@@ -247,12 +247,12 @@
 [237] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
 [238] = { 2,	TS,		SEN(kill),			"tkill"			},
 [239] = { 4,	TD|TN,		SEN(sendfile64),		"sendfile64"		},
-[240] = { 6,	0,		SEN(futex),			"futex"			},
+[240] = { 6,	0,		SEN(futex_time32),		"futex"			},
 [241] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
 [242] = { 3,	0,		SEN(sched_getaffinity),		"sched_getaffinity"	},
 [243] = { 2,	TM,		SEN(io_setup),			"io_setup"		},
 [244] = { 1,	TM,		SEN(io_destroy),		"io_destroy"		},
-[245] = { 5,	0,		SEN(io_getevents),		"io_getevents"		},
+[245] = { 5,	0,		SEN(io_getevents_time32),	"io_getevents"		},
 [246] = { 3,	0,		SEN(io_submit),			"io_submit"		},
 [247] = { 3,	0,		SEN(io_cancel),			"io_cancel"		},
 [248] = { 1,	TP|SE,		SEN(exit),			"exit_group"		},
@@ -265,14 +265,14 @@
 /* [255] - get_thread_area */
 [256] = { 1,	0,		SEN(set_tid_address),		"set_tid_address"	},
 [257] = { 3,	0,		SEN(timer_create),		"timer_create"		},
-[258] = { 4,	0,		SEN(timer_settime),		"timer_settime"		},
-[259] = { 2,	0,		SEN(timer_gettime),		"timer_gettime"		},
+[258] = { 4,	0,		SEN(timer_settime32),		"timer_settime"		},
+[259] = { 2,	0,		SEN(timer_gettime32),		"timer_gettime"		},
 [260] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
 [261] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
-[262] = { 2,	0,		SEN(clock_settime),		"clock_settime"		},
-[263] = { 2,	0,		SEN(clock_gettime),		"clock_gettime"		},
-[264] = { 2,	0,		SEN(clock_getres),		"clock_getres"		},
-[265] = { 4,	0,		SEN(clock_nanosleep),		"clock_nanosleep"	},
+[262] = { 2,	0,		SEN(clock_settime32),		"clock_settime"		},
+[263] = { 2,	0,		SEN(clock_gettime32),		"clock_gettime"		},
+[264] = { 2,	0,		SEN(clock_getres_time32),	"clock_getres"		},
+[265] = { 4,	0,		SEN(clock_nanosleep_time32),	"clock_nanosleep"	},
 [266] = { 3,	TF|TSF|TSFA,	SEN(statfs64),			"statfs64"		},
 [267] = { 3,	TD|TFSF|TSFA,	SEN(fstatfs64),			"fstatfs64"		},
 [268] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
@@ -283,8 +283,8 @@
 [273] = { 5,	0,		SEN(printargs),			"pciconfig_write"	},
 [274] = { 4,	TD,		SEN(mq_open),			"mq_open"		},
 [275] = { 1,	0,		SEN(mq_unlink),			"mq_unlink"		},
-[276] = { 5,	TD,		SEN(mq_timedsend),		"mq_timedsend"		},
-[277] = { 5,	TD,		SEN(mq_timedreceive),		"mq_timedreceive"	},
+[276] = { 5,	TD,		SEN(mq_timedsend_time32),	"mq_timedsend"		},
+[277] = { 5,	TD,		SEN(mq_timedreceive_time32),	"mq_timedreceive"	},
 [278] = { 2,	TD,		SEN(mq_notify),			"mq_notify"		},
 [279] = { 3,	TD,		SEN(mq_getsetattr),		"mq_getsetattr"		},
 [280] = { 5,	TP,		SEN(waitid),			"waitid"		},
@@ -319,7 +319,7 @@
 [309] = { 5,	0,		SEN(add_key),			"add_key"		},
 [310] = { 4,	0,		SEN(request_key),		"request_key"		},
 [311] = { 5,	0,		SEN(keyctl),			"keyctl"		},
-[312] = { 4,	TI,		SEN(semtimedop),		"semtimedop"		},
+[312] = { 4,	TI,		SEN(semtimedop_time32),		"semtimedop"		},
 [313] = { 5,	0,		SEN(vserver),			"vserver"		},
 [314] = { 3,	0,		SEN(ioprio_set),		"ioprio_set"		},
 [315] = { 2,	0,		SEN(ioprio_get),		"ioprio_get"		},
@@ -342,8 +342,8 @@
 [332] = { 4,	TD|TF,		SEN(readlinkat),		"readlinkat"		},
 [333] = { 3,	TD|TF,		SEN(fchmodat),			"fchmodat"		},
 [334] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
-[335] = { 6,	TD,		SEN(pselect6),			"pselect6"		},
-[336] = { 5,	TD,		SEN(ppoll),			"ppoll"			},
+[335] = { 6,	TD,		SEN(pselect6_time32),		"pselect6"		},
+[336] = { 5,	TD,		SEN(ppoll_time32),		"ppoll"			},
 [337] = { 1,	TP,		SEN(unshare),			"unshare"		},
 [338] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [339] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
@@ -355,13 +355,13 @@
 [345] = { 3,	0,		SEN(getcpu),			"getcpu"		},
 [346] = { 6,	TD,		SEN(epoll_pwait),		"epoll_pwait"		},
 [347] = { 4,	0,		SEN(kexec_load),		"kexec_load"		},
-[348] = { 4,	TD|TF,		SEN(utimensat),			"utimensat"		},
+[348] = { 4,	TD|TF,		SEN(utimensat_time32),		"utimensat"		},
 [349] = { 3,	TD|TS,		SEN(signalfd),			"signalfd"		},
 [350] = { 2,	TD,		SEN(timerfd_create),		"timerfd_create"	},
 [351] = { 1,	TD,		SEN(eventfd),			"eventfd"		},
 [352] = { 6,	TD,		SEN(fallocate),			"fallocate"		},
-[353] = { 4,	TD,		SEN(timerfd_settime),		"timerfd_settime"	},
-[354] = { 2,	TD,		SEN(timerfd_gettime),		"timerfd_gettime"	},
+[353] = { 4,	TD,		SEN(timerfd_settime32),		"timerfd_settime"	},
+[354] = { 2,	TD,		SEN(timerfd_gettime32),		"timerfd_gettime"	},
 [355] = { 4,	TD|TS,		SEN(signalfd4),			"signalfd4"		},
 [356] = { 2,	TD,		SEN(eventfd2),			"eventfd2"		},
 [357] = { 1,	TD,		SEN(epoll_create1),		"epoll_create1"		},
@@ -372,14 +372,14 @@
 [362] = { 5,	TD,		SEN(pwritev),			"pwritev"		},
 [363] = { 4,	TP|TS,		SEN(rt_tgsigqueueinfo),		"rt_tgsigqueueinfo"	},
 [364] = { 5,	TD,		SEN(perf_event_open),		"perf_event_open"	},
-[365] = { 5,	TN,		SEN(recvmmsg),			"recvmmsg"		},
+[365] = { 5,	TN,		SEN(recvmmsg_time32),		"recvmmsg"		},
 [366] = { 4,	TN,		SEN(accept4),			"accept4"		},
 [367] = { 2,	TD,		SEN(fanotify_init),		"fanotify_init"		},
 [368] = { 6,	TD|TF,		SEN(fanotify_mark),		"fanotify_mark"		},
 [369] = { 4,	0,		SEN(prlimit64),			"prlimit64"		},
 [370] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [371] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
-[372] = { 2,	0,		SEN(clock_adjtime),		"clock_adjtime"		},
+[372] = { 2,	0,		SEN(clock_adjtime32),		"clock_adjtime"		},
 [373] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
 [374] = { 4,	TN,		SEN(sendmmsg),			"sendmmsg"		},
 [375] = { 2,	TD,		SEN(setns),			"setns"			},
@@ -406,13 +406,18 @@
 [396] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
 [397] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
 [398] = { 4,	0,		SEN(rseq),			"rseq"			},
-[399] = { 6,	0,		SEN(io_pgetevents),		"io_pgetevents"		},
+[399] = { 6,	0,		SEN(io_pgetevents_time32),	"io_pgetevents"		},
+[400] = { 4,	TM,		SEN(migrate_pages),		"migrate_pages"		},
+[401] = { 5,	TD,		SEN(kexec_file_load),		"kexec_file_load"	},
+/* [402] - unused */
+#include "syscallent-common-32.h"
+#include "syscallent-common.h"
 
 #ifdef __ARM_EABI__
 # define ARM_FIRST_SHUFFLED_SYSCALL 500
 #else
 # define SYS_socket_subcall	500
-# include "subcall.h"
+# include "subcall32.h"
 # define ARM_FIRST_SHUFFLED_SYSCALL (SYS_ipc_subcall + SYS_ipc_nsubcalls)
 #endif /* !__ARM_EABI__ */
 
