@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
  * Copyright (c) 1993, 1994, 1995 Rick Sladkey <jrs@world.std.com>
- * Copyright (c) 1995-2018 The strace developers.
+ * Copyright (c) 1995-2019 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -131,7 +131,7 @@
 [121] = { 2,	0,		SEN(setdomainname),		"setdomainname"		},
 [122] = { 1,	0,		SEN(uname),			"uname"			},
 [123] = { 3,	0,		SEN(modify_ldt),		"modify_ldt"		},
-[124] = { 1,	0,		SEN(adjtimex),			"adjtimex"		},
+[124] = { 1,	0,		SEN(adjtimex32),		"adjtimex"		},
 [125] = { 3,	TM|SI,		SEN(mprotect),			"mprotect"		},
 [126] = { 3,	TS,		SEN(sigprocmask),		"sigprocmask"		},
 [127] = { 2,	0,		SEN(create_module),		"create_module"		},
@@ -168,14 +168,14 @@
 [158] = { 0,	0,		SEN(sched_yield),		"sched_yield"		},
 [159] = { 1,	0,		SEN(sched_get_priority_max),	"sched_get_priority_max"},
 [160] = { 1,	0,		SEN(sched_get_priority_min),	"sched_get_priority_min"},
-[161] = { 2,	0,		SEN(sched_rr_get_interval),	"sched_rr_get_interval"	},
-[162] = { 2,	0,		SEN(nanosleep),			"nanosleep"		},
+[161] = { 2,	0,		SEN(sched_rr_get_interval_time32),"sched_rr_get_interval"},
+[162] = { 2,	0,		SEN(nanosleep_time32),		"nanosleep"		},
 [163] = { 5,	TM|SI,		SEN(mremap),			"mremap"		},
 [164] = { 3,	0,		SEN(setresuid16),		"setresuid"		},
 [165] = { 3,	0,		SEN(getresuid16),		"getresuid"		},
 [166] = { 5,	0,		SEN(vm86),			"vm86"			},
 [167] = { 5,	0,		SEN(query_module),		"query_module"		},
-[168] = { 3,	TD,		SEN(poll),			"poll"			},
+[168] = { 3,	TD,		SEN(poll_time32),		"poll"			},
 [169] = { 3,	0,		SEN(nfsservctl),		"nfsservctl"		},
 [170] = { 3,	0,		SEN(setresgid16),		"setresgid"		},
 [171] = { 3,	0,		SEN(getresgid16),		"getresgid"		},
@@ -184,7 +184,7 @@
 [174] = { 4,	TS,		SEN(rt_sigaction),		"rt_sigaction"		},
 [175] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [176] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
-[177] = { 4,	TS,		SEN(rt_sigtimedwait),		"rt_sigtimedwait"	},
+[177] = { 4,	TS,		SEN(rt_sigtimedwait_time32),	"rt_sigtimedwait"	},
 [178] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [179] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [180] = { 5,	TD,		SEN(pread),			"pread"			},
@@ -246,14 +246,14 @@
 [237] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
 [238] = { 2,	TS,		SEN(kill),			"tkill"			},
 [239] = { 4,	TD|TN,		SEN(sendfile64),		"sendfile64"		},
-[240] = { 6,	0,		SEN(futex),			"futex"			},
+[240] = { 6,	0,		SEN(futex_time32),		"futex"			},
 [241] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
 [242] = { 3,	0,		SEN(sched_getaffinity),		"sched_getaffinity"	},
 [243] = { 1,	0,		SEN(set_thread_area),		"set_thread_area"	},
 [244] = { 1,	0,		SEN(get_thread_area),		"get_thread_area"	},
 [245] = { 2,	TM,		SEN(io_setup),			"io_setup"		},
 [246] = { 1,	TM,		SEN(io_destroy),		"io_destroy"		},
-[247] = { 5,	0,		SEN(io_getevents),		"io_getevents"		},
+[247] = { 5,	0,		SEN(io_getevents_time32),	"io_getevents"		},
 [248] = { 3,	0,		SEN(io_submit),			"io_submit"		},
 [249] = { 3,	0,		SEN(io_cancel),			"io_cancel"		},
 [250] = { 5,	0,		SEN(printargs),			"alloc_hugepages"	},
@@ -267,14 +267,14 @@
 [258] = { 5,	TM|SI,		SEN(remap_file_pages),		"remap_file_pages"	},
 [259] = { 1,	0,		SEN(set_tid_address),		"set_tid_address"	},
 [260] = { 3,	0,		SEN(timer_create),		"timer_create"		},
-[261] = { 4,	0,		SEN(timer_settime),		"timer_settime"		},
-[262] = { 2,	0,		SEN(timer_gettime),		"timer_gettime"		},
+[261] = { 4,	0,		SEN(timer_settime32),		"timer_settime"		},
+[262] = { 2,	0,		SEN(timer_gettime32),		"timer_gettime"		},
 [263] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
 [264] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
-[265] = { 2,	0,		SEN(clock_settime),		"clock_settime"		},
-[266] = { 2,	0,		SEN(clock_gettime),		"clock_gettime"		},
-[267] = { 2,	0,		SEN(clock_getres),		"clock_getres"		},
-[268] = { 4,	0,		SEN(clock_nanosleep),		"clock_nanosleep"	},
+[265] = { 2,	0,		SEN(clock_settime32),		"clock_settime"		},
+[266] = { 2,	0,		SEN(clock_gettime32),		"clock_gettime"		},
+[267] = { 2,	0,		SEN(clock_getres_time32),	"clock_getres"		},
+[268] = { 4,	0,		SEN(clock_nanosleep_time32),	"clock_nanosleep"	},
 [269] = { 3,	TF|TSF|TSFA,	SEN(statfs64),			"statfs64"		},
 [270] = { 3,	TD|TFSF|TSFA,	SEN(fstatfs64),			"fstatfs64"		},
 [271] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
@@ -286,8 +286,8 @@
 [277] = { 3,	TM,		SEN(set_mempolicy),		"set_mempolicy"		},
 [278] = { 4,	TD,		SEN(mq_open),			"mq_open"		},
 [279] = { 1,	0,		SEN(mq_unlink),			"mq_unlink"		},
-[280] = { 5,	TD,		SEN(mq_timedsend),		"mq_timedsend"		},
-[281] = { 5,	TD,		SEN(mq_timedreceive),		"mq_timedreceive"	},
+[280] = { 5,	TD,		SEN(mq_timedsend_time32),	"mq_timedsend"		},
+[281] = { 5,	TD,		SEN(mq_timedreceive_time32),	"mq_timedreceive"	},
 [282] = { 2,	TD,		SEN(mq_notify),			"mq_notify"		},
 [283] = { 3,	TD,		SEN(mq_getsetattr),		"mq_getsetattr"		},
 [284] = { 4,	0,		SEN(kexec_load),		"kexec_load"		},
@@ -314,8 +314,8 @@
 [305] = { 4,	TD|TF,		SEN(readlinkat),		"readlinkat"		},
 [306] = { 3,	TD|TF,		SEN(fchmodat),			"fchmodat"		},
 [307] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
-[308] = { 6,	TD,		SEN(pselect6),			"pselect6"		},
-[309] = { 5,	TD,		SEN(ppoll),			"ppoll"			},
+[308] = { 6,	TD,		SEN(pselect6_time32),		"pselect6"		},
+[309] = { 5,	TD,		SEN(ppoll_time32),		"ppoll"			},
 [310] = { 1,	TP,		SEN(unshare),			"unshare"		},
 [311] = { 2,	0,		SEN(sram_alloc),		"sram_alloc"		},
 [312] = { 1,	0,		SEN(printargs),			"sram_free"		},
@@ -353,7 +353,7 @@
 [344] = { 4,	TD,		SEN(tee),			"tee"			},
 [345] = { 4,	TD,		SEN(vmsplice),			"vmsplice"		},
 [346] = { 6,	TD,		SEN(epoll_pwait),		"epoll_pwait"		},
-[347] = { 4,	TD|TF,		SEN(utimensat),			"utimensat"		},
+[347] = { 4,	TD|TF,		SEN(utimensat_time32),		"utimensat"		},
 [348] = { 3,	TD|TS,		SEN(signalfd),			"signalfd"		},
 [349] = { 2,	TD,		SEN(timerfd_create),		"timerfd_create"	},
 [350] = { 1,	TD,		SEN(eventfd),			"eventfd"		},
@@ -363,9 +363,9 @@
 [354] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [355] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
 [356] = { 6,	TD,		SEN(fallocate),			"fallocate"		},
-[357] = { 4,	TI,		SEN(semtimedop),		"semtimedop"		},
-[358] = { 4,	TD,		SEN(timerfd_settime),		"timerfd_settime"	},
-[359] = { 2,	TD,		SEN(timerfd_gettime),		"timerfd_gettime"	},
+[357] = { 4,	TI,		SEN(semtimedop_time32),		"semtimedop"		},
+[358] = { 4,	TD,		SEN(timerfd_settime32),		"timerfd_settime"	},
+[359] = { 2,	TD,		SEN(timerfd_gettime32),		"timerfd_gettime"	},
 [360] = { 4,	TD|TS,		SEN(signalfd4),			"signalfd4"		},
 [361] = { 2,	TD,		SEN(eventfd2),			"eventfd2"		},
 [362] = { 1,	TD,		SEN(epoll_create1),		"epoll_create1"		},
@@ -376,14 +376,14 @@
 [367] = { 5,	TD,		SEN(pwritev),			"pwritev"		},
 [368] = { 4,	TP|TS,		SEN(rt_tgsigqueueinfo),		"rt_tgsigqueueinfo"	},
 [369] = { 5,	TD,		SEN(perf_event_open),		"perf_event_open"	},
-[370] = { 5,	TN,		SEN(recvmmsg),			"recvmmsg"		},
+[370] = { 5,	TN,		SEN(recvmmsg_time32),		"recvmmsg"		},
 [371] = { 2,	TD,		SEN(fanotify_init),		"fanotify_init"		},
 [372] = { 6,	TD|TF,		SEN(fanotify_mark),		"fanotify_mark"		},
 [373] = { 4,	0,		SEN(prlimit64),			"prlimit64"		},
 [374] = { 3,	0,		SEN(cacheflush),		"cacheflush"		},
 [375] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [376] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
-[377] = { 2,	0,		SEN(clock_adjtime),		"clock_adjtime"		},
+[377] = { 2,	0,		SEN(clock_adjtime32),		"clock_adjtime"		},
 [378] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
 [379] = { 2,	TD,		SEN(setns),			"setns"			},
 [380] = { 4,	TN,		SEN(sendmmsg),			"sendmmsg"		},
