@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
  * Copyright (c) 1993, 1994, 1995 Rick Sladkey <jrs@world.std.com>
- * Copyright (c) 1995-2018 The strace developers.
+ * Copyright (c) 1995-2019 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -131,7 +131,7 @@
 [121] = { 2,	0,		SEN(setdomainname),		"setdomainname"		},
 [122] = { 1,	0,		SEN(uname),			"uname"			},
 [123] = { 5,	0,		SEN(printargs),			"modify_ldt"		},
-[124] = { 1,	0,		SEN(adjtimex),			"adjtimex"		},
+[124] = { 1,	0,		SEN(adjtimex32),		"adjtimex"		},
 [125] = { 3,	TM|SI,		SEN(mprotect),			"mprotect"		},
 [126] = { 3,	TS,		SEN(sigprocmask),		"sigprocmask"		},
 [127] = { 2,	0,		SEN(create_module),		"create_module"		},
@@ -168,13 +168,13 @@
 [158] = { 0,	0,		SEN(sched_yield),		"sched_yield"		},
 [159] = { 1,	0,		SEN(sched_get_priority_max),	"sched_get_priority_max"},
 [160] = { 1,	0,		SEN(sched_get_priority_min),	"sched_get_priority_min"},
-[161] = { 2,	0,		SEN(sched_rr_get_interval),	"sched_rr_get_interval"	},
-[162] = { 2,	0,		SEN(nanosleep),			"nanosleep"		},
+[161] = { 2,	0,		SEN(sched_rr_get_interval_time32),"sched_rr_get_interval"},
+[162] = { 2,	0,		SEN(nanosleep_time32),		"nanosleep"		},
 [163] = { 5,	TM|SI,		SEN(mremap),			"mremap"		},
 [164] = { 3,	0,		SEN(setresuid),			"setresuid"		},
 [165] = { 3,	0,		SEN(getresuid),			"getresuid"		},
 [166] = { 5,	0,		SEN(query_module),		"query_module"		},
-[167] = { 3,	TD,		SEN(poll),			"poll"			},
+[167] = { 3,	TD,		SEN(poll_time32),		"poll"			},
 [168] = { 3,	0,		SEN(nfsservctl),		"nfsservctl"		},
 [169] = { 3,	0,		SEN(setresgid),			"setresgid"		},
 [170] = { 3,	0,		SEN(getresgid),			"getresgid"		},
@@ -183,7 +183,7 @@
 [173] = { 4,	TS,		SEN(rt_sigaction),		"rt_sigaction"		},
 [174] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [175] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
-[176] = { 4,	TS,		SEN(rt_sigtimedwait),		"rt_sigtimedwait"	},
+[176] = { 4,	TS,		SEN(rt_sigtimedwait_time32),	"rt_sigtimedwait"	},
 [177] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [178] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [179] = { 6,	TD,		SEN(pread),			"pread64"		},
@@ -228,7 +228,7 @@
 [218] = { 2,	TF,		SEN(removexattr),		"removexattr"		},
 [219] = { 2,	TF,		SEN(removexattr),		"lremovexattr"		},
 [220] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
-[221] = { 6,	0,		SEN(futex),			"futex"			},
+[221] = { 6,	0,		SEN(futex_time32),		"futex"			},
 [222] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
 [223] = { 3,	0,		SEN(sched_getaffinity),		"sched_getaffinity"	},
 [224] = { },
@@ -236,7 +236,7 @@
 [226] = { 4,	TD|TN,		SEN(sendfile64),		"sendfile64"		},
 [227] = { 2,	TM,		SEN(io_setup),			"io_setup"		},
 [228] = { 1,	TM,		SEN(io_destroy),		"io_destroy"		},
-[229] = { 5,	0,		SEN(io_getevents),		"io_getevents"		},
+[229] = { 5,	0,		SEN(io_getevents_time32),	"io_getevents"		},
 [230] = { 3,	0,		SEN(io_submit),			"io_submit"		},
 [231] = { 3,	0,		SEN(io_cancel),			"io_cancel"		},
 [232] = { 1,	0,		SEN(set_tid_address),		"set_tid_address"	},
@@ -248,14 +248,14 @@
 [238] = { 4,	TD,		SEN(epoll_wait),		"epoll_wait"		},
 [239] = { 5,	TM|SI,		SEN(remap_file_pages),		"remap_file_pages"	},
 [240] = { 3,	0,		SEN(timer_create),		"timer_create"		},
-[241] = { 4,	0,		SEN(timer_settime),		"timer_settime"		},
-[242] = { 2,	0,		SEN(timer_gettime),		"timer_gettime"		},
+[241] = { 4,	0,		SEN(timer_settime32),		"timer_settime"		},
+[242] = { 2,	0,		SEN(timer_gettime32),		"timer_gettime"		},
 [243] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
 [244] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
-[245] = { 2,	0,		SEN(clock_settime),		"clock_settime"		},
-[246] = { 2,	0,		SEN(clock_gettime),		"clock_gettime"		},
-[247] = { 2,	0,		SEN(clock_getres),		"clock_getres"		},
-[248] = { 4,	0,		SEN(clock_nanosleep),		"clock_nanosleep"	},
+[245] = { 2,	0,		SEN(clock_settime32),		"clock_settime"		},
+[246] = { 2,	0,		SEN(clock_gettime32),		"clock_gettime"		},
+[247] = { 2,	0,		SEN(clock_getres_time32),	"clock_getres"		},
+[248] = { 4,	0,		SEN(clock_nanosleep_time32),	"clock_nanosleep"	},
 [249] = { 2,	0,		SEN(printargs),			"swapcontext"		},
 [250] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
 [251] = { 2,	TF,		SEN(utimes),			"utimes"		},
@@ -271,8 +271,8 @@
 [261] = { 3,	TM,		SEN(set_mempolicy),		"set_mempolicy"		},
 [262] = { 4,	TD,		SEN(mq_open),			"mq_open"		},
 [263] = { 1,	0,		SEN(mq_unlink),			"mq_unlink"		},
-[264] = { 5,	TD,		SEN(mq_timedsend),		"mq_timedsend"		},
-[265] = { 5,	TD,		SEN(mq_timedreceive),		"mq_timedreceive"	},
+[264] = { 5,	TD,		SEN(mq_timedsend_time32),	"mq_timedsend"		},
+[265] = { 5,	TD,		SEN(mq_timedreceive_time32),	"mq_timedreceive"	},
 [266] = { 2,	TD,		SEN(mq_notify),			"mq_notify"		},
 [267] = { 3,	TD,		SEN(mq_getsetattr),		"mq_getsetattr"		},
 [268] = { 4,	0,		SEN(kexec_load),		"kexec_load"		},
@@ -287,8 +287,8 @@
 [277] = { 2,	TD,		SEN(inotify_rm_watch),		"inotify_rm_watch"	},
 [278] = { 3,	0,		SEN(printargs),			"spu_run"		},
 [279] = { 4,	0,		SEN(printargs),			"spu_create"		},
-[280] = { 6,	TD,		SEN(pselect6),			"pselect6"		},
-[281] = { 5,	TD,		SEN(ppoll),			"ppoll"			},
+[280] = { 6,	TD,		SEN(pselect6_time32),		"pselect6"		},
+[281] = { 5,	TD,		SEN(ppoll_time32),		"ppoll"			},
 [282] = { 1,	TP,		SEN(unshare),			"unshare"		},
 [283] = { 6,	TD,		SEN(splice),			"splice"		},
 [284] = { 4,	TD,		SEN(tee),			"tee"			},
@@ -311,15 +311,15 @@
 [301] = { 6,	TM,		SEN(move_pages),		"move_pages"		},
 [302] = { 3,	0,		SEN(getcpu),			"getcpu"		},
 [303] = { 6,	TD,		SEN(epoll_pwait),		"epoll_pwait"		},
-[304] = { 4,	TD|TF,		SEN(utimensat),			"utimensat"		},
+[304] = { 4,	TD|TF,		SEN(utimensat_time32),		"utimensat"		},
 [305] = { 3,	TD|TS,		SEN(signalfd),			"signalfd"		},
 [306] = { 2,	TD,		SEN(timerfd_create),		"timerfd_create"	},
 [307] = { 1,	TD,		SEN(eventfd),			"eventfd"		},
 [308] = { 6,	TD,		SEN(sync_file_range2),		"sync_file_range2"	},
 [309] = { 6,	TD,		SEN(fallocate),			"fallocate"		},
 [310] = { 3,	0,		SEN(subpage_prot),		"subpage_prot"		},
-[311] = { 4,	TD,		SEN(timerfd_settime),		"timerfd_settime"	},
-[312] = { 2,	TD,		SEN(timerfd_gettime),		"timerfd_gettime"	},
+[311] = { 4,	TD,		SEN(timerfd_settime32),		"timerfd_settime"	},
+[312] = { 2,	TD,		SEN(timerfd_gettime32),		"timerfd_gettime"	},
 [313] = { 4,	TD|TS,		SEN(signalfd4),			"signalfd4"		},
 [314] = { 2,	TD,		SEN(eventfd2),			"eventfd2"		},
 [315] = { 1,	TD,		SEN(epoll_create1),		"epoll_create1"		},
@@ -350,11 +350,11 @@
 [340] = { 5,	TN,		SEN(getsockopt),		"getsockopt"		},
 [341] = { 3,	TN,		SEN(sendmsg),			"sendmsg"		},
 [342] = { 3,	TN,		SEN(recvmsg),			"recvmsg"		},
-[343] = { 5,	TN,		SEN(recvmmsg),			"recvmmsg"		},
+[343] = { 5,	TN,		SEN(recvmmsg_time32),		"recvmmsg"		},
 [344] = { 4,	TN,		SEN(accept4),			"accept4"		},
 [345] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [346] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
-[347] = { 2,	0,		SEN(clock_adjtime),		"clock_adjtime"		},
+[347] = { 2,	0,		SEN(clock_adjtime32),		"clock_adjtime"		},
 [348] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
 [349] = { 4,	TN,		SEN(sendmmsg),			"sendmmsg"		},
 [350] = { 2,	TD,		SEN(setns),			"setns"			},
@@ -373,18 +373,7 @@
 [363] = { 0,	0,		SEN(printargs),			"switch_endian"		},
 [364] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd"		},
 [365] = { 2,	0,		SEN(membarrier),		"membarrier"		},
-[366] = { 3,	TI,		SEN(semop),			"semop"			},
-[367] = { 3,	TI,		SEN(semget),			"semget"		},
-[368] = { 4,	TI,		SEN(semctl),			"semctl"		},
-[369] = { 4,	TI,		SEN(semtimedop),		"semtimedop"		},
-[370] = { 4,	TI,		SEN(msgsnd),			"msgsnd"		},
-[371] = { 5,	TI,		SEN(msgrcv),			"msgrcv"		},
-[372] = { 2,	TI,		SEN(msgget),			"msgget"		},
-[373] = { 3,	TI,		SEN(msgctl),			"msgctl"		},
-[374] = { 3,	TI|TM|SI,	SEN(shmat),			"shmat"			},
-[375] = { 1,	TI|TM|SI,	SEN(shmdt),			"shmdt"			},
-[376] = { 3,	TI,		SEN(shmget),			"shmget"		},
-[377] = { 3,	TI,		SEN(shmctl),			"shmctl"		},
+/* originally left for IPC, now unused */
 [378] = { 3,	TM,		SEN(mlock2),			"mlock2"		},
 [379] = { 6,	TD,		SEN(copy_file_range),		"copy_file_range"	},
 [380] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
@@ -395,7 +384,20 @@
 [385] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
 [386] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
 [387] = { 4,	0,		SEN(rseq),			"rseq"			},
-[388] = { 6,	0,		SEN(io_pgetevents),		"io_pgetevents"		},
+[388] = { 6,	0,		SEN(io_pgetevents_time32),	"io_pgetevents"		},
+/* room for arch specific syscalls */
+[393] = { 3,	TI,		SEN(semget),			"semget"		},
+[394] = { 4,	TI,		SEN(semctl),			"semctl"		},
+[395] = { 3,	TI,		SEN(shmget),			"shmget"		},
+[396] = { 3,	TI,		SEN(shmctl),			"shmctl"		},
+[397] = { 3,	TI|TM|SI,	SEN(shmat),			"shmat"			},
+[398] = { 1,	TI|TM|SI,	SEN(shmdt),			"shmdt"			},
+[399] = { 2,	TI,		SEN(msgget),			"msgget"		},
+[400] = { 4,	TI,		SEN(msgsnd),			"msgsnd"		},
+[401] = { 5,	TI,		SEN(msgrcv),			"msgrcv"		},
+[402] = { 3,	TI,		SEN(msgctl),			"msgctl"		},
+#include "syscallent-common-32.h"
+#include "syscallent-common.h"
 
-#define SYS_socket_subcall	400
-#include "subcall.h"
+#define SYS_socket_subcall	500
+#include "subcall32.h"
