@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2000 IBM Deutschland Entwicklung GmbH, IBM Coporation
- * Copyright (c) 2000-2018 The strace developers.
+ * Copyright (c) 2000-2019 The strace developers.
  * Authors: Ulrich Weigand <Ulrich.Weigand@de.ibm.com>
  *          D.J. Barrow  <barrow_dj@mail.yahoo.com,djbarrow@de.ibm.com>
  * All rights reserved.
@@ -133,7 +133,7 @@
 [121] = { 2,	0,		SEN(setdomainname),		"setdomainname"		},
 [122] = { 1,	0,		SEN(uname),			"uname"			},
 [123] = { },
-[124] = { 1,	0,		SEN(adjtimex),			"adjtimex"		},
+[124] = { 1,	0,		SEN(adjtimex32),		"adjtimex"		},
 [125] = { 3,	TM|SI,		SEN(mprotect),			"mprotect"		},
 [126] = { 3,	TS,		SEN(sigprocmask),		"sigprocmask"		},
 [127] = { 2,	0,		SEN(create_module),		"create_module"		},
@@ -170,14 +170,14 @@
 [158] = { 0,	0,		SEN(sched_yield),		"sched_yield"		},
 [159] = { 1,	0,		SEN(sched_get_priority_max),	"sched_get_priority_max"},
 [160] = { 1,	0,		SEN(sched_get_priority_min),	"sched_get_priority_min"},
-[161] = { 2,	0,		SEN(sched_rr_get_interval),	"sched_rr_get_interval"	},
-[162] = { 2,	0,		SEN(nanosleep),			"nanosleep"		},
+[161] = { 2,	0,		SEN(sched_rr_get_interval_time32),"sched_rr_get_interval"},
+[162] = { 2,	0,		SEN(nanosleep_time32),		"nanosleep"		},
 [163] = { 5,	TM|SI,		SEN(mremap),			"mremap"		},
 [164] = { 3,	0,		SEN(setresuid16),		"setresuid"		},
 [165] = { 3,	0,		SEN(getresuid16),		"getresuid"		},
 [166] = { },
 [167] = { 5,	0,		SEN(query_module),		"query_module"		},
-[168] = { 3,	TD,		SEN(poll),			"poll"			},
+[168] = { 3,	TD,		SEN(poll_time32),		"poll"			},
 [169] = { 3,	0,		SEN(nfsservctl),		"nfsservctl"		},
 [170] = { 3,	0,		SEN(setresgid16),		"setresgid"		},
 [171] = { 3,	0,		SEN(getresgid16),		"getresgid"		},
@@ -186,7 +186,7 @@
 [174] = { 4,	TS,		SEN(rt_sigaction),		"rt_sigaction"		},
 [175] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [176] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
-[177] = { 4,	TS,		SEN(rt_sigtimedwait),		"rt_sigtimedwait"	},
+[177] = { 4,	TS,		SEN(rt_sigtimedwait_time32),	"rt_sigtimedwait"	},
 [178] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [179] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [180] = { 5,	TD,		SEN(pread),			"pread64"		},
@@ -247,14 +247,14 @@
 [235] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
 [236] = { 0,	PU|NF,		SEN(gettid),			"gettid"		},
 [237] = { 2,	TS,		SEN(kill),			"tkill"			},
-[238] = { 6,	0,		SEN(futex),			"futex"			},
+[238] = { 6,	0,		SEN(futex_time32),		"futex"			},
 [239] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
 [240] = { 3,	0,		SEN(sched_getaffinity),		"sched_getaffinity"	},
 [241] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
 [242] = { },
 [243] = { 2,	TM,		SEN(io_setup),			"io_setup"		},
 [244] = { 1,	TM,		SEN(io_destroy),		"io_destroy"		},
-[245] = { 5,	0,		SEN(io_getevents),		"io_getevents"		},
+[245] = { 5,	0,		SEN(io_getevents_time32),	"io_getevents"		},
 [246] = { 3,	0,		SEN(io_submit),			"io_submit"		},
 [247] = { 3,	0,		SEN(io_cancel),			"io_cancel"		},
 [248] = { 1,	TP|SE,		SEN(exit),			"exit_group"		},
@@ -264,14 +264,14 @@
 [252] = { 1,	0,		SEN(set_tid_address),		"set_tid_address"	},
 [253] = { 5,	TD,		SEN(fadvise64),			"fadvise64"		},
 [254] = { 3,	0,		SEN(timer_create),		"timer_create"		},
-[255] = { 4,	0,		SEN(timer_settime),		"timer_settime"		},
-[256] = { 2,	0,		SEN(timer_gettime),		"timer_gettime"		},
+[255] = { 4,	0,		SEN(timer_settime32),		"timer_settime"		},
+[256] = { 2,	0,		SEN(timer_gettime32),		"timer_gettime"		},
 [257] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
 [258] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
-[259] = { 2,	0,		SEN(clock_settime),		"clock_settime"		},
-[260] = { 2,	0,		SEN(clock_gettime),		"clock_gettime"		},
-[261] = { 2,	0,		SEN(clock_getres),		"clock_getres"		},
-[262] = { 4,	0,		SEN(clock_nanosleep),		"clock_nanosleep"	},
+[259] = { 2,	0,		SEN(clock_settime32),		"clock_settime"		},
+[260] = { 2,	0,		SEN(clock_gettime32),		"clock_gettime"		},
+[261] = { 2,	0,		SEN(clock_getres_time32),	"clock_getres"		},
+[262] = { 4,	0,		SEN(clock_nanosleep_time32),	"clock_nanosleep"	},
 [263] = { 5,	0,		SEN(vserver),			"vserver"		},
 [264] = { 6,	TD,		SEN(fadvise64_64),		"fadvise64_64"		},
 [265] = { 3,	TF|TSF|TSFA,	SEN(statfs64),			"statfs64"		},
@@ -282,8 +282,8 @@
 [270] = { 3,	TM,		SEN(set_mempolicy),		"set_mempolicy"		},
 [271] = { 4,	TD,		SEN(mq_open),			"mq_open"		},
 [272] = { 1,	0,		SEN(mq_unlink),			"mq_unlink"		},
-[273] = { 5,	TD,		SEN(mq_timedsend),		"mq_timedsend"		},
-[274] = { 5,	TD,		SEN(mq_timedreceive),		"mq_timedreceive"	},
+[273] = { 5,	TD,		SEN(mq_timedsend_time32),	"mq_timedsend"		},
+[274] = { 5,	TD,		SEN(mq_timedreceive_time32),	"mq_timedreceive"	},
 [275] = { 2,	TD,		SEN(mq_notify),			"mq_notify"		},
 [276] = { 3,	TD,		SEN(mq_getsetattr),		"mq_getsetattr"		},
 [277] = { 4,	0,		SEN(kexec_load),		"kexec_load"		},
@@ -310,8 +310,8 @@
 [298] = { 4,	TD|TF,		SEN(readlinkat),		"readlinkat"		},
 [299] = { 3,	TD|TF,		SEN(fchmodat),			"fchmodat"		},
 [300] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
-[301] = { 6,	TD,		SEN(pselect6),			"pselect6"		},
-[302] = { 5,	TD,		SEN(ppoll),			"ppoll"			},
+[301] = { 6,	TD,		SEN(pselect6_time32),		"pselect6"		},
+[302] = { 5,	TD,		SEN(ppoll_time32),		"ppoll"			},
 [303] = { 1,	TP,		SEN(unshare),			"unshare"		},
 [304] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [305] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
@@ -324,13 +324,13 @@
 [312] = { 6,	TD,		SEN(epoll_pwait),		"epoll_pwait"		},
 [313] = { 2,	TF,		SEN(utimes),			"utimes"		},
 [314] = { 6,	TD,		SEN(fallocate),			"fallocate"		},
-[315] = { 4,	TD|TF,		SEN(utimensat),			"utimensat"		},
+[315] = { 4,	TD|TF,		SEN(utimensat_time32),		"utimensat"		},
 [316] = { 3,	TD|TS,		SEN(signalfd),			"signalfd"		},
 [317] = { 4,	TD,		SEN(timerfd),			"timerfd"		},
 [318] = { 1,	TD,		SEN(eventfd),			"eventfd"		},
 [319] = { 2,	TD,		SEN(timerfd_create),		"timerfd_create"	},
-[320] = { 4,	TD,		SEN(timerfd_settime),		"timerfd_settime"	},
-[321] = { 2,	TD,		SEN(timerfd_gettime),		"timerfd_gettime"	},
+[320] = { 4,	TD,		SEN(timerfd_settime32),		"timerfd_settime"	},
+[321] = { 2,	TD,		SEN(timerfd_gettime32),		"timerfd_gettime"	},
 [322] = { 4,	TD|TS,		SEN(signalfd4),			"signalfd4"		},
 [323] = { 2,	TD,		SEN(eventfd2),			"eventfd2"		},
 [324] = { 1,	TD,		SEN(inotify_init1),		"inotify_init1"		},
@@ -346,7 +346,7 @@
 [334] = { 4,	0,		SEN(prlimit64),			"prlimit64"		},
 [335] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [336] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
-[337] = { 2,	0,		SEN(clock_adjtime),		"clock_adjtime"		},
+[337] = { 2,	0,		SEN(clock_adjtime32),		"clock_adjtime"		},
 [338] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
 [339] = { 2,	TD,		SEN(setns),			"setns"			},
 [340] = { 6,	0,		SEN(process_vm_readv),		"process_vm_readv"	},
@@ -366,7 +366,7 @@
 [354] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat"		},
 [355] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd"		},
 [356] = { 2,	0,		SEN(membarrier),		"membarrier"		},
-[357] = { 5,	TN,		SEN(recvmmsg),			"recvmmsg"		},
+[357] = { 5,	TN,		SEN(recvmmsg_time32),		"recvmmsg"		},
 [358] = { 4,	TN,		SEN(sendmmsg),			"sendmmsg"		},
 [359] = { 3,	TN,		SEN(socket),			"socket"		},
 [360] = { 4,	TN,		SEN(socketpair),		"socketpair"		},
@@ -391,8 +391,24 @@
 [379] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
 [380] = { 4,	0,		SEN(s390_sthyi),		"s390_sthyi"		},
 [381] = { 5,	TD,		SEN(kexec_file_load),		"kexec_file_load"	},
-[382] = { 6,	0,		SEN(io_pgetevents),		"io_pgetevents"		},
+[382] = { 6,	0,		SEN(io_pgetevents_time32),	"io_pgetevents"		},
 [383] = { 4,	0,		SEN(rseq),			"rseq"			},
+[384] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
+[385] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
+[386] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
+/* room for arch specific calls */
+[393] = { 3,	TI,		SEN(semget),			"semget"		},
+[394] = { 4,	TI,		SEN(semctl),			"semctl"		},
+[395] = { 3,	TI,		SEN(shmget),			"shmget"		},
+[396] = { 3,	TI,		SEN(shmctl),			"shmctl"		},
+[397] = { 3,	TI|TM|SI,	SEN(shmat),			"shmat"			},
+[398] = { 1,	TI|TM|SI,	SEN(shmdt),			"shmdt"			},
+[399] = { 2,	TI,		SEN(msgget),			"msgget"		},
+[400] = { 4,	TI,		SEN(msgsnd),			"msgsnd"		},
+[401] = { 5,	TI,		SEN(msgrcv),			"msgrcv"		},
+[402] = { 3,	TI,		SEN(msgctl),			"msgctl"		},
+#include "syscallent-common-32.h"
+#include "syscallent-common.h"
 
-#define SYS_socket_subcall	400
-#include "subcall.h"
+#define SYS_socket_subcall	500
+#include "subcall32.h"
