@@ -3,7 +3,7 @@
  * Copyright (c) 1993, 1994, 1995 Rick Sladkey <jrs@world.std.com>
  * Copyright (c) 2000 PocketPenguins Inc.  Linux for Hitachi SuperH
  *                    port by Greg Banks <gbanks@pocketpenguins.com>
- * Copyright (c) 2000-2018 The strace developers.
+ * Copyright (c) 2000-2019 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -133,7 +133,7 @@
 [121] = { 2,	0,		SEN(setdomainname),		"setdomainname"		},
 [122] = { 1,	0,		SEN(uname),			"uname"			},
 [123] = { 3,	0,		SEN(cacheflush),		"cacheflush"		},
-[124] = { 1,	0,		SEN(adjtimex),			"adjtimex"		},
+[124] = { 1,	0,		SEN(adjtimex32),		"adjtimex"		},
 [125] = { 3,	TM|SI,		SEN(mprotect),			"mprotect"		},
 [126] = { 3,	TS,		SEN(sigprocmask),		"sigprocmask"		},
 [127] = { 2,	0,		SEN(create_module),		"create_module"		},
@@ -170,14 +170,14 @@
 [158] = { 0,	0,		SEN(sched_yield),		"sched_yield"		},
 [159] = { 1,	0,		SEN(sched_get_priority_max),	"sched_get_priority_max"},
 [160] = { 1,	0,		SEN(sched_get_priority_min),	"sched_get_priority_min"},
-[161] = { 2,	0,		SEN(sched_rr_get_interval),	"sched_rr_get_interval"	},
-[162] = { 2,	0,		SEN(nanosleep),			"nanosleep"		},
+[161] = { 2,	0,		SEN(sched_rr_get_interval_time32),"sched_rr_get_interval"},
+[162] = { 2,	0,		SEN(nanosleep_time32),		"nanosleep"		},
 [163] = { 5,	TM|SI,		SEN(mremap),			"mremap"		},
 [164] = { 3,	0,		SEN(setresuid16),		"setresuid"		},
 [165] = { 3,	0,		SEN(getresuid16),		"getresuid"		},
 [166] = { 5,	0,		SEN(vm86),			"vm86"			},
 [167] = { 5,	0,		SEN(query_module),		"query_module"		},
-[168] = { 3,	TD,		SEN(poll),			"poll"			},
+[168] = { 3,	TD,		SEN(poll_time32),		"poll"			},
 [169] = { 3,	0,		SEN(nfsservctl),		"nfsservctl"		},
 [170] = { 3,	0,		SEN(setresgid16),		"setresgid"		},
 [171] = { 3,	0,		SEN(getresgid16),		"getresgid"		},
@@ -186,7 +186,7 @@
 [174] = { 4,	TS,		SEN(rt_sigaction),		"rt_sigaction"		},
 [175] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [176] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
-[177] = { 4,	TS,		SEN(rt_sigtimedwait),		"rt_sigtimedwait"	},
+[177] = { 4,	TS,		SEN(rt_sigtimedwait_time32),	"rt_sigtimedwait"	},
 [178] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [179] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [180] = { 6,	TD,		SEN(pread),			"pread64"		},
@@ -247,13 +247,13 @@
 [237] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
 [238] = { 2,	TS,		SEN(kill),			"tkill"			},
 [239] = { 4,	TD|TN,		SEN(sendfile64),		"sendfile64"		},
-[240] = { 6,	0,		SEN(futex),			"futex"			},
+[240] = { 6,	0,		SEN(futex_time32),		"futex"			},
 [241] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
 [242] = { 3,	0,		SEN(sched_getaffinity),		"sched_getaffinity"	},
 [243 ... 244] = { },
 [245] = { 2,	TM,		SEN(io_setup),			"io_setup"		},
 [246] = { 1,	TM,		SEN(io_destroy),		"io_destroy"		},
-[247] = { 5,	0,		SEN(io_getevents),		"io_getevents"		},
+[247] = { 5,	0,		SEN(io_getevents_time32),	"io_getevents"		},
 [248] = { 3,	0,		SEN(io_submit),			"io_submit"		},
 [249] = { 3,	0,		SEN(io_cancel),			"io_cancel"		},
 [250] = { 5,	TD,		SEN(fadvise64),			"fadvise64"		},
@@ -266,14 +266,14 @@
 [257] = { 5,	TM|SI,		SEN(remap_file_pages),		"remap_file_pages"	},
 [258] = { 1,	0,		SEN(set_tid_address),		"set_tid_address"	},
 [259] = { 3,	0,		SEN(timer_create),		"timer_create"		},
-[260] = { 4,	0,		SEN(timer_settime),		"timer_settime"		},
-[261] = { 2,	0,		SEN(timer_gettime),		"timer_gettime"		},
+[260] = { 4,	0,		SEN(timer_settime32),		"timer_settime"		},
+[261] = { 2,	0,		SEN(timer_gettime32),		"timer_gettime"		},
 [262] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
 [263] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
-[264] = { 2,	0,		SEN(clock_settime),		"clock_settime"		},
-[265] = { 2,	0,		SEN(clock_gettime),		"clock_gettime"		},
-[266] = { 2,	0,		SEN(clock_getres),		"clock_getres"		},
-[267] = { 4,	0,		SEN(clock_nanosleep),		"clock_nanosleep"	},
+[264] = { 2,	0,		SEN(clock_settime32),		"clock_settime"		},
+[265] = { 2,	0,		SEN(clock_gettime32),		"clock_gettime"		},
+[266] = { 2,	0,		SEN(clock_getres_time32),	"clock_getres"		},
+[267] = { 4,	0,		SEN(clock_nanosleep_time32),	"clock_nanosleep"	},
 [268] = { 3,	TF|TSF|TSFA,	SEN(statfs64),			"statfs64"		},
 [269] = { 3,	TD|TFSF|TSFA,	SEN(fstatfs64),			"fstatfs64"		},
 [270] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
@@ -285,8 +285,8 @@
 [276] = { 3,	TM,		SEN(set_mempolicy),		"set_mempolicy"		},
 [277] = { 4,	TD,		SEN(mq_open),			"mq_open"		},
 [278] = { 1,	0,		SEN(mq_unlink),			"mq_unlink"		},
-[279] = { 5,	TD,		SEN(mq_timedsend),		"mq_timedsend"		},
-[280] = { 5,	TD,		SEN(mq_timedreceive),		"mq_timedreceive"	},
+[279] = { 5,	TD,		SEN(mq_timedsend_time32),	"mq_timedsend"		},
+[280] = { 5,	TD,		SEN(mq_timedreceive_time32),	"mq_timedreceive"	},
 [281] = { 2,	TD,		SEN(mq_notify),			"mq_notify"		},
 [282] = { 3,	TD,		SEN(mq_getsetattr),		"mq_getsetattr"		},
 [283] = { 4,	0,		SEN(kexec_load),		"kexec_load"		},
@@ -314,8 +314,8 @@
 [305] = { 4,	TD|TF,		SEN(readlinkat),		"readlinkat"		},
 [306] = { 3,	TD|TF,		SEN(fchmodat),			"fchmodat"		},
 [307] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
-[308] = { 6,	TD,		SEN(pselect6),			"pselect6"		},
-[309] = { 5,	TD,		SEN(ppoll),			"ppoll"			},
+[308] = { 6,	TD,		SEN(pselect6_time32),		"pselect6"		},
+[309] = { 5,	TD,		SEN(ppoll_time32),		"ppoll"			},
 [310] = { 1,	TP,		SEN(unshare),			"unshare"		},
 [311] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [312] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
@@ -326,13 +326,13 @@
 [317] = { 6,	TM,		SEN(move_pages),		"move_pages"		},
 [318] = { 3,	0,		SEN(getcpu),			"getcpu"		},
 [319] = { 6,	TD,		SEN(epoll_pwait),		"epoll_pwait"		},
-[320] = { 4,	TD|TF,		SEN(utimensat),			"utimensat"		},
+[320] = { 4,	TD|TF,		SEN(utimensat_time32),		"utimensat"		},
 [321] = { 3,	TD|TS,		SEN(signalfd),			"signalfd"		},
 [322] = { 2,	TD,		SEN(timerfd_create),		"timerfd_create"	},
 [323] = { 1,	TD,		SEN(eventfd),			"eventfd"		},
 [324] = { 6,	TD,		SEN(fallocate),			"fallocate"		},
-[325] = { 4,	TD,		SEN(timerfd_settime),		"timerfd_settime"	},
-[326] = { 2,	TD,		SEN(timerfd_gettime),		"timerfd_gettime"	},
+[325] = { 4,	TD,		SEN(timerfd_settime32),		"timerfd_settime"	},
+[326] = { 2,	TD,		SEN(timerfd_gettime32),		"timerfd_gettime"	},
 [327] = { 4,	TD|TS,		SEN(signalfd4),			"signalfd4"		},
 [328] = { 2,	TD,		SEN(eventfd2),			"eventfd2"		},
 [329] = { 1,	TD,		SEN(epoll_create1),		"epoll_create1"		},
@@ -363,11 +363,11 @@
 [354] = { 5,	TN,		SEN(getsockopt),		"getsockopt"		},
 [355] = { 3,	TN,		SEN(sendmsg),			"sendmsg"		},
 [356] = { 3,	TN,		SEN(recvmsg),			"recvmsg"		},
-[357] = { 5,	TN,		SEN(recvmmsg),			"recvmmsg"		},
+[357] = { 5,	TN,		SEN(recvmmsg_time32),		"recvmmsg"		},
 [358] = { 4,	TN,		SEN(accept4),			"accept4"		},
 [359] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [360] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
-[361] = { 2,	0,		SEN(clock_adjtime),		"clock_adjtime"		},
+[361] = { 2,	0,		SEN(clock_adjtime32),		"clock_adjtime"		},
 [362] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
 [363] = { 4,	TN,		SEN(sendmmsg),			"sendmmsg"		},
 [364] = { 2,	TD,		SEN(setns),			"setns"			},
@@ -389,6 +389,24 @@
 [380] = { 6,	TD,		SEN(copy_file_range),		"copy_file_range"	},
 [381] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
 [382] = { 6,	TD,		SEN(pwritev2),			"pwritev2"		},
+[383] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[384] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
+[385] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
+[386] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
+[387] = { 4,	0,		SEN(rseq),			"rseq"			},
+/* room for arch specific calls */
+[393] = { 3,	TI,		SEN(semget),			"semget"		},
+[394] = { 4,	TI,		SEN(semctl),			"semctl"		},
+[395] = { 3,	TI,		SEN(shmget),			"shmget"		},
+[396] = { 3,	TI,		SEN(shmctl),			"shmctl"		},
+[397] = { 3,	TI|TM|SI,	SEN(shmat),			"shmat"			},
+[398] = { 1,	TI|TM|SI,	SEN(shmdt),			"shmdt"			},
+[399] = { 2,	TI,		SEN(msgget),			"msgget"		},
+[400] = { 4,	TI,		SEN(msgsnd),			"msgsnd"		},
+[401] = { 5,	TI,		SEN(msgrcv),			"msgrcv"		},
+[402] = { 3,	TI,		SEN(msgctl),			"msgctl"		},
+#include "syscallent-common-32.h"
+#include "syscallent-common.h"
 
-#define SYS_socket_subcall	400
-#include "subcall.h"
+#define SYS_socket_subcall	500
+#include "subcall32.h"
