@@ -399,10 +399,7 @@
 [392] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
 [393] = { 6,	TD,		SEN(pwritev2),			"pwritev2"		},
 /* [403 ... 423] - reserved to sync up with other architectures */
-[424] = { 4,	TD|TS,		SEN(pidfd_send_signal),		"pidfd_send_signal"	},
-[425] = { 2,	TD,		SEN(io_uring_setup),		"io_uring_setup"	},
-[426] = { 6,	TD|TS,		SEN(io_uring_enter),		"io_uring_enter"	},
-[427] = { 4,	TD|TM,		SEN(io_uring_register),		"io_uring_register"	},
+#include "syscallent-common.h"
 
 #define SYS_socket_subcall	500
 #include "subcall64.h"
