@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999-2018 The strace developers.
+ * Copyright (c) 1999-2019 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -110,7 +110,7 @@
 [102] = { 5,	TS,		SEN(rt_sigaction),		"rt_sigaction"		},
 [103] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [104] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
-[105] = { 4,	TS,		SEN(rt_sigtimedwait),		"rt_sigtimedwait"	},
+[105] = { 4,	TS,		SEN(rt_sigtimedwait_time32),	"rt_sigtimedwait"	},
 [106] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [107] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [108] = { 3,	0,		SEN(setresuid),			"setresuid32"		},
@@ -147,7 +147,7 @@
 [139] = { 2,	TF|TST|TSTA,	SEN(stat64),			"stat64"		},
 [140] = { 4,	TD|TN,		SEN(sendfile64),		"sendfile64"		},
 [141] = { 3,	TN,		SEN(getpeername),		"getpeername"		},
-[142] = { 6,	0,		SEN(futex),			"futex"			},
+[142] = { 6,	0,		SEN(futex_time32),		"futex"			},
 [143] = { 0,	PU|NF,		SEN(gettid),			"gettid"		},
 [144] = { 2,	0,		SEN(getrlimit),			"getrlimit"		},
 [145] = { 2,	0,		SEN(setrlimit),			"setrlimit"		},
@@ -158,7 +158,7 @@
 [150] = { 3,	TN,		SEN(getsockname),		"getsockname"		},
 [151] = { 0,	TD,		SEN(inotify_init),		"inotify_init"		},
 [152] = { 3,	TD|TF,		SEN(inotify_add_watch),		"inotify_add_watch"	},
-[153] = { 3,	TD,		SEN(poll),			"poll"			},
+[153] = { 3,	TD,		SEN(poll_time32),		"poll"			},
 [154] = { 3,	TD,		SEN(getdents64),		"getdents64"		},
 [155] = { 3,	TD,		SEN(fcntl64),			"fcntl64"		},
 [156] = { 2,	TD,		SEN(inotify_rm_watch),		"inotify_rm_watch"	},
@@ -224,7 +224,7 @@
 [216] = { 0,	TS,		SEN(sigreturn),			"sigreturn"		},
 [217] = { 5,	TP,		SEN(clone),			"clone"			},
 [218] = { 2,	0,		SEN(ioprio_get),		"ioprio_get"		},
-[219] = { 1,	0,		SEN(adjtimex),			"adjtimex"		},
+[219] = { 1,	0,		SEN(adjtimex32),		"adjtimex"		},
 [220] = { 3,	TS,		SEN(sigprocmask),		"sigprocmask"		},
 [221] = { 2,	0,		SEN(create_module),		"create_module"		},
 [222] = { 2,	0,		SEN(delete_module),		"delete_module"		},
@@ -253,22 +253,22 @@
 [245] = { 0,	0,		SEN(sched_yield),		"sched_yield"		},
 [246] = { 1,	0,		SEN(sched_get_priority_max),	"sched_get_priority_max"},
 [247] = { 1,	0,		SEN(sched_get_priority_min),	"sched_get_priority_min"},
-[248] = { 2,	0,		SEN(sched_rr_get_interval),	"sched_rr_get_interval"	},
-[249] = { 2,	0,		SEN(nanosleep),			"nanosleep"		},
+[248] = { 2,	0,		SEN(sched_rr_get_interval_time32),"sched_rr_get_interval"},
+[249] = { 2,	0,		SEN(nanosleep_time32),		"nanosleep"		},
 [250] = { 5,	TM|SI,		SEN(mremap),			"mremap"		},
 [251] = { 1,	0,		SEN(sysctl),			"_sysctl"		},
 [252] = { 1,	0,		SEN(getsid),			"getsid"		},
 [253] = { 1,	TD,		SEN(fdatasync),			"fdatasync"		},
 [254] = { 3,	0,		SEN(nfsservctl),		"nfsservctl"		},
 [255] = { 6,	TD,		SEN(sync_file_range),		"sync_file_range"	},
-[256] = { 2,	0,		SEN(clock_settime),		"clock_settime"		},
-[257] = { 2,	0,		SEN(clock_gettime),		"clock_gettime"		},
-[258] = { 2,	0,		SEN(clock_getres),		"clock_getres"		},
-[259] = { 4,	0,		SEN(clock_nanosleep),		"clock_nanosleep"	},
+[256] = { 2,	0,		SEN(clock_settime32),		"clock_settime"		},
+[257] = { 2,	0,		SEN(clock_gettime32),		"clock_gettime"		},
+[258] = { 2,	0,		SEN(clock_getres_time32),	"clock_getres"		},
+[259] = { 4,	0,		SEN(clock_nanosleep_time32),	"clock_nanosleep"	},
 [260] = { 3,	0,		SEN(sched_getaffinity),		"sched_getaffinity"	},
 [261] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
-[262] = { 4,	0,		SEN(timer_settime),		"timer_settime"		},
-[263] = { 2,	0,		SEN(timer_gettime),		"timer_gettime"		},
+[262] = { 4,	0,		SEN(timer_settime32),		"timer_settime"		},
+[263] = { 2,	0,		SEN(timer_gettime32),		"timer_gettime"		},
 [264] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
 [265] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
 [266] = { 3,	0,		SEN(timer_create),		"timer_create"		},
@@ -277,11 +277,11 @@
 [269] = { 1,	TM,		SEN(io_destroy),		"io_destroy"		},
 [270] = { 3,	0,		SEN(io_submit),			"io_submit"		},
 [271] = { 3,	0,		SEN(io_cancel),			"io_cancel"		},
-[272] = { 5,	0,		SEN(io_getevents),		"io_getevents"		},
+[272] = { 5,	0,		SEN(io_getevents_time32),	"io_getevents"		},
 [273] = { 4,	TD,		SEN(mq_open),			"mq_open"		},
 [274] = { 1,	0,		SEN(mq_unlink),			"mq_unlink"		},
-[275] = { 5,	TD,		SEN(mq_timedsend),		"mq_timedsend"		},
-[276] = { 5,	TD,		SEN(mq_timedreceive),		"mq_timedreceive"	},
+[275] = { 5,	TD,		SEN(mq_timedsend_time32),	"mq_timedsend"		},
+[276] = { 5,	TD,		SEN(mq_timedreceive_time32),	"mq_timedreceive"	},
 [277] = { 2,	TD,		SEN(mq_notify),			"mq_notify"		},
 [278] = { 3,	TD,		SEN(mq_getsetattr),		"mq_getsetattr"		},
 [279] = { 5,	TP,		SEN(waitid),			"waitid"		},
@@ -302,8 +302,8 @@
 [294] = { 4,	TD|TF,		SEN(readlinkat),		"readlinkat"		},
 [295] = { 3,	TD|TF,		SEN(fchmodat),			"fchmodat"		},
 [296] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
-[297] = { 6,	TD,		SEN(pselect6),			"pselect6"		},
-[298] = { 5,	TD,		SEN(ppoll),			"ppoll"			},
+[297] = { 6,	TD,		SEN(pselect6_time32),		"pselect6"		},
+[298] = { 5,	TD,		SEN(ppoll_time32),		"ppoll"			},
 [299] = { 1,	TP,		SEN(unshare),			"unshare"		},
 [300] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [301] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
@@ -315,13 +315,13 @@
 [307] = { 6,	TM,		SEN(move_pages),		"move_pages"		},
 [308] = { 3,	0,		SEN(getcpu),			"getcpu"		},
 [309] = { 6,	TD,		SEN(epoll_pwait),		"epoll_pwait"		},
-[310] = { 4,	TD|TF,		SEN(utimensat),			"utimensat"		},
+[310] = { 4,	TD|TF,		SEN(utimensat_time32),		"utimensat"		},
 [311] = { 3,	TD|TS,		SEN(signalfd),			"signalfd"		},
 [312] = { 2,	TD,		SEN(timerfd_create),		"timerfd_create"	},
 [313] = { 1,	TD,		SEN(eventfd),			"eventfd"		},
 [314] = { 6,	TD,		SEN(fallocate),			"fallocate"		},
-[315] = { 4,	TD,		SEN(timerfd_settime),		"timerfd_settime"	},
-[316] = { 2,	TD,		SEN(timerfd_gettime),		"timerfd_gettime"	},
+[315] = { 4,	TD,		SEN(timerfd_settime32),		"timerfd_settime"	},
+[316] = { 2,	TD,		SEN(timerfd_gettime32),		"timerfd_gettime"	},
 [317] = { 4,	TD|TS,		SEN(signalfd4),			"signalfd4"		},
 [318] = { 2,	TD,		SEN(eventfd2),			"eventfd2"		},
 [319] = { 1,	TD,		SEN(epoll_create1),		"epoll_create1"		},
@@ -333,13 +333,13 @@
 [325] = { 5,	TD,		SEN(pwritev),			"pwritev"		},
 [326] = { 4,	TP|TS,		SEN(rt_tgsigqueueinfo),		"rt_tgsigqueueinfo"	},
 [327] = { 5,	TD,		SEN(perf_event_open),		"perf_event_open"	},
-[328] = { 5,	TN,		SEN(recvmmsg),			"recvmmsg"		},
+[328] = { 5,	TN,		SEN(recvmmsg_time32),		"recvmmsg"		},
 [329] = { 2,	TD,		SEN(fanotify_init),		"fanotify_init"		},
 [330] = { 6,	TD|TF,		SEN(fanotify_mark),		"fanotify_mark"		},
 [331] = { 4,	0,		SEN(prlimit64),			"prlimit64"		},
 [332] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [333] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
-[334] = { 2,	0,		SEN(clock_adjtime),		"clock_adjtime"		},
+[334] = { 2,	0,		SEN(clock_adjtime32),		"clock_adjtime"		},
 [335] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
 [336] = { 4,	TN,		SEN(sendmmsg),			"sendmmsg"		},
 [337] = { 2,	TD,		SEN(setns),			"setns"			},
@@ -366,7 +366,24 @@
 [358] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
 [359] = { 6,	TD,		SEN(pwritev2),			"pwritev2"		},
 [360] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
-[361] = { 6,	0,		SEN(io_pgetevents),		"io_pgetevents"		},
+[361] = { 6,	0,		SEN(io_pgetevents_time32),	"io_pgetevents"		},
+[362] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
+[363] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
+[364] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
+[365] = { 4,	0,		SEN(rseq),			"rseq"			},
+/* room for arch specific calls */
+[393] = { 3,	TI,		SEN(semget),			"semget"		},
+[394] = { 4,	TI,		SEN(semctl),			"semctl"		},
+[395] = { 3,	TI,		SEN(shmget),			"shmget"		},
+[396] = { 3,	TI,		SEN(shmctl),			"shmctl"		},
+[397] = { 3,	TI|TM|SI,	SEN(shmat),			"shmat"			},
+[398] = { 1,	TI|TM|SI,	SEN(shmdt),			"shmdt"			},
+[399] = { 2,	TI,		SEN(msgget),			"msgget"		},
+[400] = { 4,	TI,		SEN(msgsnd),			"msgsnd"		},
+[401] = { 5,	TI,		SEN(msgrcv),			"msgrcv"		},
+[402] = { 3,	TI,		SEN(msgctl),			"msgctl"		},
+#include "syscallent-common-32.h"
+#include "syscallent-common.h"
 
-#define SYS_socket_subcall	400
-#include "subcall.h"
+#define SYS_socket_subcall	500
+#include "subcall32.h"
