@@ -341,7 +341,4 @@
 [333] = { 6,	0,		SEN(io_pgetevents_time64),	"io_pgetevents"		},
 [334] = { 4,	0,		SEN(rseq),			"rseq"			},
 /* [335 ... 423] - reserved to sync up with other architectures */
-[424] = { 4,	TD|TS,		SEN(pidfd_send_signal),		"pidfd_send_signal"	},
-[425] = { 2,	TD,		SEN(io_uring_setup),		"io_uring_setup"	},
-[426] = { 6,	TD|TS,		SEN(io_uring_enter),		"io_uring_enter"	},
-[427] = { 4,	TD|TM,		SEN(io_uring_register),		"io_uring_register"	},
+#include "syscallent-common.h"
