@@ -2,30 +2,10 @@
  * Check bpf syscall decoding.
  *
  * Copyright (c) 2015-2017 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2019 The strace developers.
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. The name of the author may not be used to endorse or promote products
- *    derived from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
- * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
- * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
- * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
@@ -91,6 +71,10 @@ union bpf_attr_data {
 	BPF_ATTR_DATA_FIELD(BPF_OBJ_GET_INFO_BY_FD);
 	BPF_ATTR_DATA_FIELD(BPF_PROG_QUERY);
 	BPF_ATTR_DATA_FIELD(BPF_RAW_TRACEPOINT_OPEN);
+	BPF_ATTR_DATA_FIELD(BPF_BTF_LOAD);
+	BPF_ATTR_DATA_FIELD(BPF_BTF_GET_FD_BY_ID);
+	BPF_ATTR_DATA_FIELD(BPF_TASK_FD_QUERY);
+	BPF_ATTR_DATA_FIELD(BPF_MAP_FREEZE);
 	char char_data[256];
 };
 
@@ -276,7 +260,7 @@ static struct bpf_attr_check BPF_MAP_CREATE_checks[] = {
 	},
 	{ /* 1 */
 		.data = { .BPF_MAP_CREATE_data = {
-			.map_type = 18,
+			.map_type = 20,
 			.key_size = 4,
 			.value_size = 8,
 			.max_entries = 256,
@@ -286,7 +270,7 @@ static struct bpf_attr_check BPF_MAP_CREATE_checks[] = {
 			.map_name = "0123456789abcde",
 		} },
 		.size = offsetof(struct BPF_MAP_CREATE_struct, map_name) + 8,
-		.str = "map_type=BPF_MAP_TYPE_SOCKHASH, key_size=4"
+		.str = "map_type=BPF_MAP_TYPE_REUSEPORT_SOCKARRAY, key_size=4"
 		       ", value_size=8, max_entries=256"
 		       ", map_flags=BPF_F_NO_PREALLOC|BPF_F_NO_COMMON_LRU"
 				   "|BPF_F_NUMA_NODE|BPF_F_RDONLY|BPF_F_WRONLY"
@@ -298,21 +282,21 @@ static struct bpf_attr_check BPF_MAP_CREATE_checks[] = {
 	},
 	{ /* 2 */
 		.data = { .BPF_MAP_CREATE_data = {
-			.map_type = 19,
+			.map_type = 25,
 			.key_size = 0xface1e55,
 			.value_size = 0xbadc0ded,
 			.max_entries = 0xbeefcafe,
-			.map_flags = 0xffffffc0,
+			.map_flags = 0xfffffe00,
 			.inner_map_fd = 2718281828,
 			.numa_node = -1,
 			.map_name = "",
 			.map_ifindex = 3141592653,
 		} },
 		.size = offsetofend(struct BPF_MAP_CREATE_struct, map_ifindex),
-		.str = "map_type=0x13 /* BPF_MAP_TYPE_??? */"
+		.str = "map_type=0x19 /* BPF_MAP_TYPE_??? */"
 		       ", key_size=4207812181, value_size=3134983661"
 		       ", max_entries=3203386110"
-		       ", map_flags=0xffffffc0 /* BPF_F_??? */"
+		       ", map_flags=0xfffffe00 /* BPF_F_??? */"
 		       ", inner_map_fd=-1576685468"
 		       ", map_name=\"\", map_ifindex=3141592653",
 
@@ -333,7 +317,7 @@ static struct bpf_attr_check BPF_MAP_CREATE_checks[] = {
 		       ", max_entries=3203386110"
 		       ", map_flags=BPF_F_NO_PREALLOC|BPF_F_NUMA_NODE"
 				   "|BPF_F_RDONLY|BPF_F_STACK_BUILD_ID"
-				   "|0xc0dede80",
+				   "|BPF_F_RDONLY_PROG|0xc0dede00",
 	},
 	{ /* 4 */
 		.data = { .BPF_MAP_CREATE_data = {
@@ -351,7 +335,7 @@ static struct bpf_attr_check BPF_MAP_CREATE_checks[] = {
 		       ", max_entries=3203386110"
 		       ", map_flags=BPF_F_NO_PREALLOC|BPF_F_NUMA_NODE"
 				   "|BPF_F_RDONLY|BPF_F_STACK_BUILD_ID"
-				   "|0xc0dede80"
+				   "|BPF_F_RDONLY_PROG|0xc0dede00"
 		       ", inner_map_fd=-1576685468",
 	},
 	{ /* 5 */
@@ -370,7 +354,7 @@ static struct bpf_attr_check BPF_MAP_CREATE_checks[] = {
 		       ", max_entries=3203386110"
 		       ", map_flags=BPF_F_NO_PREALLOC|BPF_F_NUMA_NODE"
 				   "|BPF_F_RDONLY|BPF_F_STACK_BUILD_ID"
-				   "|0xc0dede80"
+				   "|BPF_F_RDONLY_PROG|0xc0dede00"
 		       ", inner_map_fd=-1576685468"
 		       ", numa_node=4294967295 /* NUMA_NO_NODE */",
 	},
@@ -391,7 +375,7 @@ static struct bpf_attr_check BPF_MAP_CREATE_checks[] = {
 		       ", max_entries=3203386110"
 		       ", map_flags=BPF_F_NO_PREALLOC|BPF_F_NUMA_NODE"
 				   "|BPF_F_RDONLY|BPF_F_STACK_BUILD_ID"
-				   "|0xc0dede80"
+				   "|BPF_F_RDONLY_PROG|0xc0dede00"
 		       ", inner_map_fd=-1576685468"
 		       ", numa_node=4294967295 /* NUMA_NO_NODE */"
 		       ", map_name=\"fedcba987654321\"...",
@@ -413,13 +397,33 @@ static struct bpf_attr_check BPF_MAP_CREATE_checks[] = {
 		       ", max_entries=3203386110"
 		       ", map_flags=BPF_F_NO_PREALLOC|BPF_F_NUMA_NODE"
 				   "|BPF_F_RDONLY|BPF_F_STACK_BUILD_ID"
-				   "|0xc0dede80"
+				   "|BPF_F_RDONLY_PROG|0xc0dede00"
 		       ", inner_map_fd=-1576685468"
 		       ", numa_node=4294967295 /* NUMA_NO_NODE */"
 		       ", map_name=\"0123456789abcde\""
 		       ", map_ifindex=" IFINDEX_LO_STR,
 		.init_fn = init_BPF_MAP_CREATE_attr7,
 	},
+	{ /* 8 */
+		.data = { .BPF_MAP_CREATE_data = {
+			.btf_fd = 0xbadc0ded,
+			.btf_key_type_id = 0xfacefeed,
+			.btf_value_type_id = 0xcafef00d
+		} },
+		.size = offsetofend(struct BPF_MAP_CREATE_struct,
+				    btf_value_type_id),
+		.str = "map_type=BPF_MAP_TYPE_UNSPEC"
+		       ", key_size=0"
+		       ", value_size=0"
+		       ", max_entries=0"
+		       ", map_flags=0"
+		       ", inner_map_fd=0"
+		       ", map_name=\"\""
+		       ", map_ifindex=0"
+		       ", btf_fd=-1159983635"
+		       ", btf_key_type_id=4207869677"
+		       ", btf_value_type_id=3405705229"
+	},
 };
 
 static const struct bpf_attr_check BPF_MAP_LOOKUP_ELEM_checks[] = {
@@ -439,6 +443,8 @@ static const struct bpf_attr_check BPF_MAP_LOOKUP_ELEM_checks[] = {
 	}
 };
 
+#define BPF_MAP_LOOKUP_AND_DELETE_ELEM_checks BPF_MAP_LOOKUP_ELEM_checks
+
 static const struct bpf_attr_check BPF_MAP_UPDATE_ELEM_checks[] = {
 	{
 		.data = { .BPF_MAP_UPDATE_ELEM_data = { .map_fd = -1 } },
@@ -491,6 +497,14 @@ static const struct bpf_attr_check BPF_MAP_GET_NEXT_KEY_checks[] = {
 	}
 };
 
+static const struct bpf_attr_check BPF_MAP_FREEZE_checks[] = {
+	{
+		.data = { .BPF_MAP_FREEZE_data = { .map_fd = -1 } },
+		.size = offsetofend(struct BPF_MAP_FREEZE_struct, map_fd),
+		.str = "map_fd=-1"
+	}
+};
+
 static const struct bpf_insn insns[] = {
 	{
 		.code = 0x95,
@@ -551,7 +565,7 @@ print_BPF_PROG_LOAD_attr3(const struct bpf_attr_check *check, unsigned long addr
 	       ", insns=" INSNS_FMT ", license=\"%s\", log_level=2718281828"
 	       ", log_size=%u, log_buf=%p"
 	       ", kern_version=KERNEL_VERSION(51966, 240, 13)"
-	       ", prog_flags=0x2 /* BPF_F_??? */"
+	       ", prog_flags=0x4 /* BPF_F_??? */"
 	       ", prog_name=\"0123456789abcde\"..., prog_ifindex=3203399405",
 	       (unsigned int) ARRAY_SIZE(insns), INSNS_ARG, license,
 	       log_buf_size, get_log_buf_tail());
@@ -577,7 +591,7 @@ print_BPF_PROG_LOAD_attr4(const struct bpf_attr_check *check, unsigned long addr
 	       ", license=\"%s\", log_level=2718281828, log_size=4"
 	       ", log_buf=\"log \"..."
 	       ", kern_version=KERNEL_VERSION(51966, 240, 13)"
-	       ", prog_flags=BPF_F_STRICT_ALIGNMENT|0x2"
+	       ", prog_flags=BPF_F_STRICT_ALIGNMENT|BPF_F_ANY_ALIGNMENT|0x4"
 	       ", prog_name=\"0123456789abcde\"..., prog_ifindex=%s"
 	       ", expected_attach_type=BPF_CGROUP_INET6_BIND",
 	       (unsigned int) ARRAY_SIZE(insns), INSNS_ARG,
@@ -593,7 +607,7 @@ static struct bpf_attr_check BPF_PROG_LOAD_checks[] = {
 	},
 	{ /* 1 */
 		.data = { .BPF_PROG_LOAD_data = {
-			.prog_type = 20,
+			.prog_type = 24,
 			.insn_cnt = 0xbadc0ded,
 			.insns = 0,
 			.license = 0,
@@ -604,7 +618,7 @@ static struct bpf_attr_check BPF_PROG_LOAD_checks[] = {
 			.prog_flags = 0,
 		} },
 		.size = offsetofend(struct BPF_PROG_LOAD_struct, prog_flags),
-		.str = "prog_type=0x14 /* BPF_PROG_TYPE_??? */"
+		.str = "prog_type=0x18 /* BPF_PROG_TYPE_??? */"
 		       ", insn_cnt=3134983661, insns=NULL, license=NULL"
 		       ", log_level=42, log_size=3141592653, log_buf=NULL"
 		       ", kern_version=KERNEL_VERSION(51966, 240, 13)"
@@ -612,7 +626,7 @@ static struct bpf_attr_check BPF_PROG_LOAD_checks[] = {
 	},
 	{ /* 2 */
 		.data = { .BPF_PROG_LOAD_data = {
-			.prog_type = 19,
+			.prog_type = 20,
 			.insn_cnt = 0xbadc0ded,
 			.insns = 0xffffffff00000000,
 			.license = 0xffffffff00000000,
@@ -624,7 +638,7 @@ static struct bpf_attr_check BPF_PROG_LOAD_checks[] = {
 			.prog_name = "fedcba987654321",
 		} },
 		.size = offsetofend(struct BPF_PROG_LOAD_struct, prog_name),
-		.str = "prog_type=BPF_PROG_TYPE_LIRC_MODE2"
+		.str = "prog_type=BPF_PROG_TYPE_SK_REUSEPORT"
 		       ", insn_cnt=3134983661"
 		       ", insns=" BIG_ADDR("0xffffffff00000000", "NULL")
 		       ", license=" BIG_ADDR("0xffffffff00000000", "NULL")
@@ -641,7 +655,7 @@ static struct bpf_attr_check BPF_PROG_LOAD_checks[] = {
 			.log_level = 2718281828U,
 			.log_size = log_buf_size,
 			.kern_version = 0xcafef00d,
-			.prog_flags = 2,
+			.prog_flags = 4,
 			.prog_name = "0123456789abcdef",
 			.prog_ifindex = 0xbeeffeed,
 		} },
@@ -656,7 +670,7 @@ static struct bpf_attr_check BPF_PROG_LOAD_checks[] = {
 			.log_level = 2718281828U,
 			.log_size = 4,
 			.kern_version = 0xcafef00d,
-			.prog_flags = 3,
+			.prog_flags = 7,
 			.prog_name = "0123456789abcdef",
 			.expected_attach_type = 9,
 		} },
@@ -665,6 +679,40 @@ static struct bpf_attr_check BPF_PROG_LOAD_checks[] = {
 		.init_fn = init_BPF_PROG_LOAD_attr4,
 		.print_fn = print_BPF_PROG_LOAD_attr4
 	},
+	{ /* 5 */
+		.data = { .BPF_PROG_LOAD_data = {
+			.prog_flags = 2,
+			.expected_attach_type = 17,
+			.prog_btf_fd = 0xbadc0ded,
+			.func_info_rec_size = 0xdad1bef2,
+			.func_info = 0xfac1fed2fac3fed4,
+			.func_info_cnt = 0xdad3bef4,
+			.line_info_rec_size = 0xdad5bef6,
+			.line_info = 0xfac5fed5fac7fed8,
+			.line_info_cnt = 0xdad7bef8
+		} },
+		.size = offsetofend(struct BPF_PROG_LOAD_struct,
+				    line_info_cnt),
+		.str = "prog_type=BPF_PROG_TYPE_UNSPEC"
+		       ", insn_cnt=0"
+		       ", insns=NULL"
+		       ", license=NULL"
+		       ", log_level=0"
+		       ", log_size=0"
+		       ", log_buf=NULL"
+		       ", kern_version=KERNEL_VERSION(0, 0, 0)"
+		       ", prog_flags=BPF_F_ANY_ALIGNMENT"
+		       ", prog_name=\"\""
+		       ", prog_ifindex=0"
+		       ", expected_attach_type=BPF_FLOW_DISSECTOR"
+		       ", prog_btf_fd=-1159983635"
+		       ", func_info_rec_size=3671178994"
+		       ", func_info=0xfac1fed2fac3fed4"
+		       ", func_info_cnt=3671310068"
+		       ", line_info_rec_size=3671441142"
+		       ", line_info=0xfac5fed5fac7fed8"
+		       ", line_info_cnt=3671572216"
+	},
 };
 
 static void
@@ -771,6 +819,33 @@ static const struct bpf_attr_check BPF_PROG_TEST_RUN_checks[] = {
 		       ", data_in=0xfacef11dbadc2ded"
 		       ", data_out=0xfacef33dbadc4ded"
 		       ", repeat=4207410904, duration=4207541978}"
+	},
+	{
+		.data = { .BPF_PROG_TEST_RUN_data = {
+			.prog_fd = -1,
+			.retval = 0xfac1fed2,
+			.data_size_in = 0xfac3fed4,
+			.data_size_out = 0xfac5fed6,
+			.data_in = (uint64_t) 0xfacef11dbadc2dedULL,
+			.data_out = (uint64_t) 0xfacef33dbadc4dedULL,
+			.repeat = 0xfac7fed8,
+			.duration = 0xfac9feda,
+			.ctx_size_in = 0xfacbfedc,
+			.ctx_size_out = 0xfacdfede,
+			.ctx_in = (uint64_t) 0xfacef55dbadc6dedULL,
+			.ctx_out = (uint64_t) 0xfacef77dbadc8dedULL
+		} },
+		.size = offsetofend(struct BPF_PROG_TEST_RUN_struct, ctx_out),
+		.str = "test={prog_fd=-1, retval=4207017682"
+		       ", data_size_in=4207148756, data_size_out=4207279830"
+		       ", data_in=0xfacef11dbadc2ded"
+		       ", data_out=0xfacef33dbadc4ded"
+		       ", repeat=4207410904"
+		       ", duration=4207541978"
+		       ", ctx_size_in=4207673052"
+		       ", ctx_size_out=4207804126"
+		       ", ctx_in=0xfacef55dbadc6ded"
+		       ", ctx_out=0xfacef77dbadc8ded}"
 	}
 };
 
@@ -978,7 +1053,7 @@ static struct bpf_attr_check BPF_PROG_QUERY_checks[] = {
 	{ /* 2 */
 		.data = { .BPF_PROG_QUERY_data = {
 			.target_fd = 3141592653U,
-			.attach_type = 17,
+			.attach_type = 21,
 			.query_flags = 0xfffffffe,
 			.attach_flags = 0xfffffffc,
 			.prog_ids = 0xffffffffffffffffULL,
@@ -986,7 +1061,7 @@ static struct bpf_attr_check BPF_PROG_QUERY_checks[] = {
 		} },
 		.size = offsetofend(struct BPF_PROG_QUERY_struct, prog_cnt),
 		.str = "query={target_fd=-1153374643"
-		       ", attach_type=0x11 /* BPF_??? */"
+		       ", attach_type=0x15 /* BPF_??? */"
 		       ", query_flags=0xfffffffe /* BPF_F_QUERY_??? */"
 		       ", attach_flags=0xfffffffc /* BPF_F_??? */"
 		       ", prog_ids="
@@ -1078,6 +1153,86 @@ static struct bpf_attr_check BPF_RAW_TRACEPOINT_OPEN_checks[] = {
 	}
 };
 
+static void
+init_BPF_BTF_LOAD_attr(struct bpf_attr_check *check)
+{
+	static const char sample_btf_data[] = "bPf\0daTum";
+
+	static char *btf_data;
+	if (!btf_data)
+		btf_data = tail_memdup(sample_btf_data,
+				       sizeof(sample_btf_data) - 1);
+
+	struct BPF_BTF_LOAD_struct *attr = &check->data.BPF_BTF_LOAD_data;
+	attr->btf = (uintptr_t) btf_data;
+}
+
+static struct bpf_attr_check BPF_BTF_LOAD_checks[] = {
+	{
+		.data = { .BPF_BTF_LOAD_data = { .btf = 0 } },
+		.size = offsetofend(struct BPF_BTF_LOAD_struct, btf),
+		.str = "btf=NULL, btf_log_buf=NULL, btf_size=0"
+		       ", btf_log_size=0, btf_log_level=0"
+	},
+	{ /* 1 */
+		.data = { .BPF_BTF_LOAD_data = {
+			.btf_log_buf = 0xfacefeeddeadbeefULL,
+			.btf_size = 9,
+			.btf_log_size = -1U,
+			.btf_log_level = 42
+		} },
+		.size = offsetofend(struct BPF_BTF_LOAD_struct, btf_log_level),
+		.init_fn = init_BPF_BTF_LOAD_attr,
+		.str = "btf=\"bPf\\0daTum\""
+		       ", btf_log_buf=0xfacefeeddeadbeef"
+		       ", btf_size=9"
+		       ", btf_log_size=4294967295"
+		       ", btf_log_level=42"
+	}
+};
+
+static const struct bpf_attr_check BPF_BTF_GET_FD_BY_ID_checks[] = {
+	{
+		.data = { .BPF_BTF_GET_FD_BY_ID_data = { .btf_id = 0xdeadbeef } },
+		.size = offsetofend(struct BPF_BTF_GET_FD_BY_ID_struct, btf_id),
+		.str = "btf_id=3735928559"
+	}
+};
+
+static const struct bpf_attr_check BPF_TASK_FD_QUERY_checks[] = {
+	{
+		.data = { .BPF_TASK_FD_QUERY_data = { .pid = 0xdeadbeef } },
+		.size = offsetofend(struct BPF_TASK_FD_QUERY_struct, pid),
+		.str = "task_fd_query={pid=3735928559, fd=0, flags=0"
+		       ", buf_len=0, buf=NULL, prog_id=0"
+		       ", fd_type=BPF_FD_TYPE_RAW_TRACEPOINT"
+		       ", probe_offset=0, probe_addr=0}"
+	},
+	{ /* 1 */
+		.data = { .BPF_TASK_FD_QUERY_data = {
+			.pid = 0xcafef00d,
+			.fd = 0xdeadbeef,
+			.flags = 0xfacefeed,
+			.buf_len = 0xdefaced,
+			.buf = 0xfffffffffffffffe,
+			.prog_id = 0xbadc0ded,
+			.fd_type = 5,
+			.probe_offset = 0xfac1fed2fac3fed4,
+			.probe_addr = 0xfac5fed5fac7fed8
+		} },
+		.size = offsetofend(struct BPF_TASK_FD_QUERY_struct, probe_addr),
+		.str = "task_fd_query={pid=3405705229"
+		       ", fd=-559038737"
+		       ", flags=4207869677"
+		       ", buf_len=233811181"
+		       ", buf=" BIG_ADDR("0xfffffffffffffffe", "0xfffffffe")
+		       ", prog_id=3134983661"
+		       ", fd_type=BPF_FD_TYPE_URETPROBE"
+		       ", probe_offset=0xfac1fed2fac3fed4"
+		       ", probe_addr=0xfac5fed5fac7fed8}"
+	}
+};
+
 
 #define CHK(cmd_) \
 	{ \
@@ -1108,6 +1263,11 @@ main(void)
 		CHK(BPF_OBJ_GET_INFO_BY_FD),
 		CHK(BPF_PROG_QUERY),
 		CHK(BPF_RAW_TRACEPOINT_OPEN),
+		CHK(BPF_BTF_LOAD),
+		CHK(BPF_BTF_GET_FD_BY_ID),
+		CHK(BPF_TASK_FD_QUERY),
+		CHK(BPF_MAP_LOOKUP_AND_DELETE_ELEM),
+		CHK(BPF_MAP_FREEZE),
 	};
 
 	page_size = get_page_size();
