@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2019 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -30,7 +30,7 @@ main(void)
 	printf("linkat(%s, \"%s\", %s, \"%s\", %s) = %ld %s (%m)\n",
 	       "AT_FDCWD", sample_1, "AT_FDCWD", sample_2,
 	       "AT_SYMLINK_NOFOLLOW|AT_REMOVEDIR|AT_SYMLINK_FOLLOW"
-	       "|AT_NO_AUTOMOUNT|AT_EMPTY_PATH|0xffffe0ff",
+	       "|AT_NO_AUTOMOUNT|AT_EMPTY_PATH|AT_RECURSIVE|0xffff60ff",
 	       rc, errno2name());
 
 	puts("+++ exited with 0 +++");
