@@ -1,38 +1,29 @@
 /*
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2019 The strace developers.
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. The name of the author may not be used to endorse or promote products
- *    derived from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
- * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
- * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
- * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef STRACE_TESTS_H
-#define STRACE_TESTS_H
+# define STRACE_TESTS_H
 
 # ifdef HAVE_CONFIG_H
 #  include "config.h"
 # endif
 
+# ifdef TESTS_SIZEOF_KERNEL_LONG_T
+#  undef SIZEOF_KERNEL_LONG_T
+#  define SIZEOF_KERNEL_LONG_T TESTS_SIZEOF_KERNEL_LONG_T
+# endif
+
+# ifdef TESTS_SIZEOF_LONG
+#  undef SIZEOF_LONG
+#  define SIZEOF_LONG TESTS_SIZEOF_LONG
+# endif
+
+# include <stdbool.h>
 # include <sys/types.h>
 # include "kernel_types.h"
 # include "gcc_compat.h"
@@ -42,19 +33,27 @@
  * The printf-like function to use in header files
  * shared between strace and its tests.
  */
-#ifndef STRACE_PRINTF
-# define STRACE_PRINTF printf
-#endif
+# ifndef STRACE_PRINTF
+#  define STRACE_PRINTF printf
+# endif
 
 /* Tests of "strace -v" are expected to define VERBOSE to 1. */
-#ifndef VERBOSE
-# define VERBOSE 0
-#endif
+# ifndef VERBOSE
+#  define VERBOSE 0
+# endif
 
-#ifndef DEFAULT_STRLEN
+/* xlat verbosity defaults */
+# ifndef XLAT_RAW
+#  define XLAT_RAW 0
+# endif
+# ifndef XLAT_VERBOSE
+#  define XLAT_VERBOSE 0
+# endif
+
+# ifndef DEFAULT_STRLEN
 /* Default maximum # of bytes printed in printstr et al. */
-# define DEFAULT_STRLEN 32
-#endif
+#  define DEFAULT_STRLEN 32
+# endif
 
 /* Cached sysconf(_SC_PAGESIZE). */
 size_t get_page_size(void);
@@ -75,14 +74,14 @@ void error_msg_and_skip(const char *, ...)
 void perror_msg_and_skip(const char *, ...)
 	ATTRIBUTE_FORMAT((printf, 1, 2)) ATTRIBUTE_NORETURN;
 
-#ifndef perror_msg_and_fail
-# define perror_msg_and_fail(fmt_, ...) \
+# ifndef perror_msg_and_fail
+#  define perror_msg_and_fail(fmt_, ...) \
 	perror_msg_and_fail("%s:%d: " fmt_, __FILE__, __LINE__, ##__VA_ARGS__)
-#endif
-#ifndef perror_msg_and_fail
-# define error_msg_and_fail(fmt_, ...) \
+# endif
+# ifndef perror_msg_and_fail
+#  define error_msg_and_fail(fmt_, ...) \
 	error_msg_and_fail("%s:%d: " fmt_, __FILE__, __LINE__, ##__VA_ARGS__)
-#endif
+# endif
 
 /* Stat the specified file and skip the test if the stat call failed. */
 void skip_if_unavailable(const char *);
@@ -98,12 +97,15 @@ void *tail_alloc(const size_t)
 void *tail_memdup(const void *, const size_t)
 	ATTRIBUTE_MALLOC ATTRIBUTE_ALLOC_SIZE((2));
 
+# define midtail_alloc(after_, before_) \
+	((void *) ((char *) tail_alloc(((before_) + (after_))) + (before_)))
+
 /*
  * Allocate an object of the specified type at the end
  * of a mapped memory region.
  * Assign its address to the specified constant pointer.
  */
-#define TAIL_ALLOC_OBJECT_CONST_PTR(type_name, type_ptr)	\
+# define TAIL_ALLOC_OBJECT_CONST_PTR(type_name, type_ptr)	\
 	type_name *const type_ptr = tail_alloc(sizeof(*type_ptr))
 
 /*
@@ -111,7 +113,7 @@ void *tail_memdup(const void *, const size_t)
  * of a mapped memory region.
  * Assign its address to the specified variable pointer.
  */
-#define TAIL_ALLOC_OBJECT_VAR_PTR(type_name, type_ptr)		\
+# define TAIL_ALLOC_OBJECT_VAR_PTR(type_name, type_ptr)		\
 	type_name *type_ptr = tail_alloc(sizeof(*type_ptr))
 
 /*
@@ -120,7 +122,7 @@ void *tail_memdup(const void *, const size_t)
  * sign, byte order and/or alignment errors.
  */
 void fill_memory_ex(void *ptr, size_t size, unsigned char start,
-		    unsigned char period);
+		    unsigned int period);
 /* Shortcut for fill_memory_ex(ptr, size, 0x80, 0x80) */
 void fill_memory(void *ptr, size_t size);
 
@@ -140,6 +142,9 @@ const char *hexquote_strndup(const char *, size_t);
 /* Return inode number of socket descriptor. */
 unsigned long inode_of_sockfd(int);
 
+/* Print string in a quoted form with optional escape characters. */
+void print_quoted_string_ex(const char *, bool quote, const char *escape_str);
+
 /* Print string in a quoted form. */
 void print_quoted_string(const char *);
 
@@ -149,6 +154,16 @@ void print_quoted_string(const char *);
  */
 void print_quoted_cstring(const char *str, size_t size);
 
+/*
+ * Print a NUL-terminated string `str' of length up to `size'
+ * in a quoted form.
+ */
+void print_quoted_stringn(const char *str, size_t size);
+
+/* Print memory in a quoted form with optional escape characters. */
+void print_quoted_memory_ex(const void *, size_t, bool quote,
+			    const char *escape_chars);
+
 /* Print memory in a quoted form. */
 void print_quoted_memory(const void *, size_t);
 
@@ -193,6 +208,9 @@ int printxval(const struct xlat *, const unsigned long long, const char *);
 int socketcall(const int nr, const int call,
 	       long a1, long a2, long a3, long a4, long a5);
 
+/* Call chdir and print strace output depending on flags. */
+void test_status_chdir(const char *dir, bool print_success, bool print_fail);
+
 /* Wrappers for recvmmsg and sendmmsg syscalls. */
 struct mmsghdr;
 struct timespec;
@@ -201,7 +219,7 @@ int send_mmsg(int, struct mmsghdr *, unsigned int, unsigned int);
 
 /* Create a netlink socket. */
 int create_nl_socket_ext(int proto, const char *name);
-#define create_nl_socket(proto)	create_nl_socket_ext((proto), #proto)
+# define create_nl_socket(proto)	create_nl_socket_ext((proto), #proto)
 
 /* Create a pipe with maximized descriptor numbers. */
 void pipe_maxfd(int pipefd[2]);
@@ -209,14 +227,14 @@ void pipe_maxfd(int pipefd[2]);
 /* if_nametoindex("lo") */
 unsigned int ifindex_lo(void);
 
-#ifdef HAVE_IF_INDEXTONAME
-# define IFINDEX_LO_STR "if_nametoindex(\"lo\")"
-#else
-# define IFINDEX_LO_STR "1"
-#endif
+# ifdef HAVE_IF_INDEXTONAME
+#  define IFINDEX_LO_STR "if_nametoindex(\"lo\")"
+# else
+#  define IFINDEX_LO_STR "1"
+# endif
 
-#define F8ILL_KULONG_SUPPORTED	(sizeof(void *) < sizeof(kernel_ulong_t))
-#define F8ILL_KULONG_MASK	((kernel_ulong_t) 0xffffffff00000000ULL)
+# define F8ILL_KULONG_SUPPORTED	(sizeof(void *) < sizeof(kernel_ulong_t))
+# define F8ILL_KULONG_MASK	((kernel_ulong_t) 0xffffffff00000000ULL)
 
 /*
  * For 64-bit kernel_ulong_t and 32-bit pointer,
@@ -234,7 +252,7 @@ f8ill_ptr_to_kulong(const void *const ptr)
 # define LENGTH_OF(arg) ((unsigned int) sizeof(arg) - 1)
 
 /* Zero-extend a signed integer type to unsigned long long. */
-#define zero_extend_signed_to_ull(v) \
+# define zero_extend_signed_to_ull(v) \
 	(sizeof(v) == sizeof(char) ? (unsigned long long) (unsigned char) (v) : \
 	 sizeof(v) == sizeof(short) ? (unsigned long long) (unsigned short) (v) : \
 	 sizeof(v) == sizeof(int) ? (unsigned long long) (unsigned int) (v) : \
@@ -242,7 +260,7 @@ f8ill_ptr_to_kulong(const void *const ptr)
 	 (unsigned long long) (v))
 
 /* Sign-extend an unsigned integer type to long long. */
-#define sign_extend_unsigned_to_ll(v) \
+# define sign_extend_unsigned_to_ll(v) \
 	(sizeof(v) == sizeof(char) ? (long long) (char) (v) : \
 	 sizeof(v) == sizeof(short) ? (long long) (short) (v) : \
 	 sizeof(v) == sizeof(int) ? (long long) (int) (v) : \
@@ -259,7 +277,6 @@ f8ill_ptr_to_kulong(const void *const ptr)
 # endif
 # define LL_VAL_TO_PAIR(llval) LL_PAIR((long) ((llval) >> 32), (long) (llval))
 
-# define _STR(_arg) #_arg
 # define ARG_STR(_arg) (_arg), #_arg
 # define ARG_ULL_STR(_arg) _arg##ULL, #_arg
 
@@ -267,12 +284,12 @@ f8ill_ptr_to_kulong(const void *const ptr)
  * Assign an object of type DEST_TYPE at address DEST_ADDR
  * using memcpy to avoid potential unaligned access.
  */
-#define SET_STRUCT(DEST_TYPE, DEST_ADDR, ...)						\
+# define SET_STRUCT(DEST_TYPE, DEST_ADDR, ...)						\
 	do {										\
 		DEST_TYPE dest_type_tmp_var = { __VA_ARGS__ };				\
 		memcpy(DEST_ADDR, &dest_type_tmp_var, sizeof(dest_type_tmp_var));	\
 	} while (0)
 
-#define NLMSG_ATTR(nlh, hdrlen) ((void *)(nlh) + NLMSG_SPACE(hdrlen))
+# define NLMSG_ATTR(nlh, hdrlen) ((void *)(nlh) + NLMSG_SPACE(hdrlen))
 
 #endif /* !STRACE_TESTS_H */
